# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 没有权限。
AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 操作访问密钥错误。
FAILEDOPERATION_ACCESSKEY = 'FailedOperation.Accesskey'

# 用户策略数超过上限。
FAILEDOPERATION_POLICYFULL = 'FailedOperation.PolicyFull'

# PolicyName字段指定的策略名已存在。
FAILEDOPERATION_POLICYNAMEINUSE = 'FailedOperation.PolicyNameInUse'

# 该策略版本已经是默认策略版本。
FAILEDOPERATION_POLICYVERSIONALREADYDEFAULT = 'FailedOperation.PolicyVersionAlreadyDefault'

# 策略版本数已经达到上限。
FAILEDOPERATION_POLICYVERSIONFULL = 'FailedOperation.PolicyVersionFull'

# 绑定标签失败。
FAILEDOPERATION_TAGRESOURCEFAILED = 'FailedOperation.TagResourceFailed'

# 解绑标签失败。
FAILEDOPERATION_UNTAGRESOURCEFAILED = 'FailedOperation.UnTagResourceFailed'

# 用户未绑定手机。
FAILEDOPERATION_USERNOTBINDPHONE = 'FailedOperation.UserNotBindPhone'

# 用户未绑定微信。
FAILEDOPERATION_USERNOTBINDWECHAT = 'FailedOperation.UserNotBindWechat'

# 设置的用户没有权限。
FAILEDOPERATION_USERUNBINDNOPERMISSION = 'FailedOperation.UserUnbindNoPermission'

# 内部错误。
INTERNALERROR = 'InternalError'

# 内部错误。
INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 策略文档的Action字段不合法。
INVALIDPARAMETER_ACTIONERROR = 'InvalidParameter.ActionError'

# 策略语法中操作不存在。
INVALIDPARAMETER_ACTIONMISS = 'InvalidParameter.ActionMiss'

# 策略语法中操作不存在。
INVALIDPARAMETER_ACTIONNOTEXIST = 'InvalidParameter.ActionNotExist'

# 策略语法中操作服务不存在。
INVALIDPARAMETER_ACTIONSERVICENOTEXIST = 'InvalidParameter.ActionServiceNotExist'

# principal字段的授权对象关联策略数已达到上限。
INVALIDPARAMETER_ATTACHMENTFULL = 'InvalidParameter.AttachmentFull'

# 策略语法中条件内容不正确。
INVALIDPARAMETER_CONDITIONCONTENTERROR = 'InvalidParameter.ConditionContentError'

# 策略文档的condition字段不合法。
INVALIDPARAMETER_CONDITIONERROR = 'InvalidParameter.ConditionError'

# 策略语法中条件操作符不正确。
INVALIDPARAMETER_CONDITIONTYPEERROR = 'InvalidParameter.ConditionTypeError'

# 任务不存在。
INVALIDPARAMETER_DELETIONTASKNOTEXIST = 'InvalidParameter.DeletionTaskNotExist'

# Description入参长度不能大于300字节。
INVALIDPARAMETER_DESCRIPTIONLENGTHOVERLIMIT = 'InvalidParameter.DescriptionLengthOverlimit'

# 策略文档的Effect字段不合法。
INVALIDPARAMETER_EFFECTERROR = 'InvalidParameter.EffectError'

# EntityFilter字段不合法。
INVALIDPARAMETER_ENTITYFILTERERROR = 'InvalidParameter.EntityFilterError'

# 用户组数量达到上限。
INVALIDPARAMETER_GROUPFULL = 'InvalidParameter.GroupFull'

# GroupId字段不合法。
INVALIDPARAMETER_GROUPIDERROR = 'InvalidParameter.GroupIdError'

# 用户组名称重复。
INVALIDPARAMETER_GROUPNAMEINUSE = 'InvalidParameter.GroupNameInUse'

# 用户组不存在。
INVALIDPARAMETER_GROUPNOTEXIST = 'InvalidParameter.GroupNotExist'

# 用户组中的子用户数量达到上限。
INVALIDPARAMETER_GROUPUSERFULL = 'InvalidParameter.GroupUserFull'

# 身份提供商名称已经使用。
INVALIDPARAMETER_IDENTITYNAMEINUSE = 'InvalidParameter.IdentityNameInUse'

# Keyword字段不合法。
INVALIDPARAMETER_KEYWORDERROR = 'InvalidParameter.KeywordError'

# 多因子Token验证失败。
INVALIDPARAMETER_MFATOKENERROR = 'InvalidParameter.MFATokenError'

# CAM不支持策略文档中所指定的资源类型。
INVALIDPARAMETER_NOTSUPPORTPRODUCT = 'InvalidParameter.NotSupportProduct'

# 一次操作实体数过多。
INVALIDPARAMETER_OPERATEENTITIESOVERLIMIT = 'InvalidParameter.OperateEntitiesOverLimit'

# 非法入参。
INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'

# 密码不符合用户安全设置。
INVALIDPARAMETER_PASSWORDVIOLATEDRULES = 'InvalidParameter.PasswordViolatedRules'

# PolicyDocument字段不合法。
INVALIDPARAMETER_POLICYDOCUMENTERROR = 'InvalidParameter.PolicyDocumentError'

# PolicyDocument字段超过长度限制。
INVALIDPARAMETER_POLICYDOCUMENTLENGTHOVERLIMIT = 'InvalidParameter.PolicyDocumentLengthOverLimit'

# 输入参数PolicyId不合法。
INVALIDPARAMETER_POLICYIDERROR = 'InvalidParameter.PolicyIdError'

# 策略ID不存在。
INVALIDPARAMETER_POLICYIDNOTEXIST = 'InvalidParameter.PolicyIdNotExist'

# PolicyName字段不合法。
INVALIDPARAMETER_POLICYNAMEERROR = 'InvalidParameter.PolicyNameError'

# 策略版本不存在。
INVALIDPARAMETER_POLICYVERSIONNOTEXISTS = 'InvalidParameter.PolicyVersionNotExists'

# 策略文档的principal字段不合法。
INVALIDPARAMETER_PRINCIPALERROR = 'InvalidParameter.PrincipalError'

# 角色载体不允许跨站。
INVALIDPARAMETER_PRINCIPALQCSCROSSERROR = 'InvalidParameter.PrincipalQcsCrossError'

# PrincipalQcsc错误。
INVALIDPARAMETER_PRINCIPALQCSERROR = 'InvalidParameter.PrincipalQcsError'

# PrincipalQcs不存在。
INVALIDPARAMETER_PRINCIPALQCSNOTEXIST = 'InvalidParameter.PrincipalQcsNotExist'

# PrincipalService不存在。
INVALIDPARAMETER_PRINCIPALSERVICENOTEXIST = 'InvalidParameter.PrincipalServiceNotExist'

# 策略语法中资源内容不正确。
INVALIDPARAMETER_RESOURCECONTENTERROR = 'InvalidParameter.ResourceContentError'

# 策略文档的Resource字段不合法。
INVALIDPARAMETER_RESOURCEERROR = 'InvalidParameter.ResourceError'

# 策略语法中资源项目不正确。
INVALIDPARAMETER_RESOURCEPROJECTERROR = 'InvalidParameter.ResourceProjectError'

# 资源QCS错误。
INVALIDPARAMETER_RESOURCEQCSERROR = 'InvalidParameter.ResourceQcsError'

# 策略语法中资源地域不正确。
INVALIDPARAMETER_RESOURCEREGIONERROR = 'InvalidParameter.ResourceRegionError'

# 策略语法中资源服务不存在。
INVALIDPARAMETER_RESOURCESERVICENOTEXIST = 'InvalidParameter.ResourceServiceNotExist'

# 策略语法中资源所属主账号不正确。
INVALIDPARAMETER_RESOURCEUINERROR = 'InvalidParameter.ResourceUinError'

# 角色数量达到上限。
INVALIDPARAMETER_ROLEFULL = 'InvalidParameter.RoleFull'

# 角色名不合法。
INVALIDPARAMETER_ROLENAMEERROR = 'InvalidParameter.RoleNameError'

# 相同名称的角色已存在。
INVALIDPARAMETER_ROLENAMEINUSE = 'InvalidParameter.RoleNameInUse'

# 角色不存在。
INVALIDPARAMETER_ROLENOTEXIST = 'InvalidParameter.RoleNotExist'

# Scope字段不合法。
INVALIDPARAMETER_SCOPEERROR = 'InvalidParameter.ScopeError'

# 权限边界不能用服务相关策略。
INVALIDPARAMETER_SERVICELINKEDPOLICYCANTINPERMISSIONBOUNDARY = 'InvalidParameter.ServiceLinkedPolicyCantInPermissionBoundary'

# 服务相关角色不能使用权限边界。
INVALIDPARAMETER_SERVICELINKEDROLECANTUSEPERMISSIONBOUNDARY = 'InvalidParameter.ServiceLinkedRoleCantUsePermissionBoundary'

# ServiceType字段不合法。
INVALIDPARAMETER_SERVICETYPEERROR = 'InvalidParameter.ServiceTypeError'

# 策略文档的Statement字段不合法。
INVALIDPARAMETER_STATEMENTERROR = 'InvalidParameter.StatementError'

# 子帐号数量达到上限。
INVALIDPARAMETER_SUBUSERFULL = 'InvalidParameter.SubUserFull'

# 子用户名称重复。
INVALIDPARAMETER_SUBUSERNAMEINUSE = 'InvalidParameter.SubUserNameInUse'

# 超出标签限制。
INVALIDPARAMETER_TAGLIMITEXCEEDED = 'InvalidParameter.TagLimitExceeded'

# 标签参数错误。
INVALIDPARAMETER_TAGPARAMERROR = 'InvalidParameter.TagParamError'

# Uin字段不合法。
INVALIDPARAMETER_UINERROR = 'InvalidParameter.UinError'

# 子用户加入的用户组数量达到上限。
INVALIDPARAMETER_USERGROUPFULL = 'InvalidParameter.UserGroupFull'

# 用户名不合法。
INVALIDPARAMETER_USERNAMEILLEGAL = 'InvalidParameter.UserNameIllegal'

# 用户对象不存在。
INVALIDPARAMETER_USERNOTEXIST = 'InvalidParameter.UserNotExist'

# 用户的Uin和Uid不能都为空。
INVALIDPARAMETER_USERUINANDUINNOTALLNULL = 'InvalidParameter.UserUinAndUinNotAllNull'

# 策略文档的Version字段不合法。
INVALIDPARAMETER_VERSIONERROR = 'InvalidParameter.VersionError'

# OIDC签名公钥错误。
INVALIDPARAMETERVALUE_IDENTITYKEYERROR = 'InvalidParameterValue.IdentityKeyError'

# 身份提供商URL错误。
INVALIDPARAMETERVALUE_IDENTITYURLERROR = 'InvalidParameterValue.IdentityUrlError'

# 身份提供商元数据文档错误。
INVALIDPARAMETERVALUE_METADATAERROR = 'InvalidParameterValue.MetadataError'

# 身份提供商名称错误。
INVALIDPARAMETERVALUE_NAMEERROR = 'InvalidParameterValue.NameError'

# 身份提供商已达到上限。
LIMITEXCEEDED_IDENTITYFULL = 'LimitExceeded.IdentityFull'

# 每个账号最多支持两个AccessKey。
OPERATIONDENIED_ACCESSKEYOVERLIMIT = 'OperationDenied.AccessKeyOverLimit'

# 存在未删除的API密钥。
OPERATIONDENIED_HAVEKEYS = 'OperationDenied.HaveKeys'

# 子用户不允许操作主账号密钥。
OPERATIONDENIED_SUBUIN = 'OperationDenied.SubUin'

# 被操作密钥与账号不匹配。
OPERATIONDENIED_UINNOTMATCH = 'OperationDenied.UinNotMatch'

# 创建子用户频率超过限制。
REQUESTLIMITEXCEEDED_CREATEUSER = 'RequestLimitExceeded.CreateUser'

# 用户账号超出了限制。
REQUESTLIMITEXCEEDED_UINLIMITEXCEEDED = 'RequestLimitExceeded.UinLimitExceeded'

# 用户组不存在。
RESOURCENOTFOUND_GROUPNOTEXIST = 'ResourceNotFound.GroupNotExist'

# 身份提供商不存在。
RESOURCENOTFOUND_IDENTITYNOTEXIST = 'ResourceNotFound.IdentityNotExist'

# 资源不存在。
RESOURCENOTFOUND_NOTFOUND = 'ResourceNotFound.NotFound'

# PolicyId指定的资源不存在。
RESOURCENOTFOUND_POLICYIDNOTFOUND = 'ResourceNotFound.PolicyIdNotFound'

# 密钥不存在。
RESOURCENOTFOUND_SECRETNOTEXIST = 'ResourceNotFound.SecretNotExist'

# 用户不存在。
RESOURCENOTFOUND_USERNOTEXIST = 'ResourceNotFound.UserNotExist'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# 没有删除API密钥权限。
UNAUTHORIZEDOPERATION_DELETEAPIKEY = 'UnauthorizedOperation.DeleteApiKey'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.ams.v20201229 import models


class AmsClient(AbstractClient):
    _apiVersion = '2020-12-29'
    _endpoint = 'ams.tencentcloudapi.com'
    _service = 'ams'


    def CancelTask(self, request):
        """可使用该接口取消审核任务。请求成功后，接口返回RequestId则说明取消成功。<br>默认接口请求频率限制：**20次/秒**。

        :param request: Request instance for CancelTask.
        :type request: :class:`tencentcloud.ams.v20201229.models.CancelTaskRequest`
        :rtype: :class:`tencentcloud.ams.v20201229.models.CancelTaskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CancelTask", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CancelTaskResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateAudioModerationSyncTask(self, request):
        """本接口（CreateAudioModerationSyncTask） 用于提交短音频内容进行智能审核任务，使用前请您使用腾讯云主账号登录控制台 [开通音频内容安全服务](https://console.cloud.tencent.com/cms/audio/package) 并调整好对应的业务配置。

        ### 接口使用说明：
        - 前往“[内容安全控制台-图片内容安全](https://console.cloud.tencent.com/cms/audio/package)”开启使用音频内容安全服务，首次开通服务的用户可免费领用试用套餐包，包含**10小时**免费调用时长，有效期为1个月。
        - 该接口为收费接口，计费方式敬请参见 [腾讯云音频内容安全定价](https://cloud.tencent.com/product/ams/pricing)。

        ### 接口调用说明：
        - 音频文件大小支持：**文件 < 5M**;
        - 音频文件**时长小于60s**，超过60s音频调用则报错；
        - 音频文件支持格式：**wav (PCM编码)** 、**mp3**、**m4a** (采样率：16kHz~48kHz，位深：16bit 小端，声道数：单声道/双声道，建议格式：**16kHz/16bit/单声道**)；
        - 接口仅限音频文件传入，视频文件传入请调用长音频异步接口；
        - 接口**默认QPS为20**，如需自定义配置并发或请求频率，请工单咨询；
        - 接口**默认超时为5s**，请求如超过该时长则接口会报错。

        :param request: Request instance for CreateAudioModerationSyncTask.
        :type request: :class:`tencentcloud.ams.v20201229.models.CreateAudioModerationSyncTaskRequest`
        :rtype: :class:`tencentcloud.ams.v20201229.models.CreateAudioModerationSyncTaskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateAudioModerationSyncTask", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateAudioModerationSyncTaskResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateAudioModerationTask(self, request):
        """本接口（Audio Moderation）用于提交音频内容（包括音频文件或流地址）进行智能审核任务，使用前请您使用腾讯云主账号登录控制台[开通音频内容安全服务](https://console.cloud.tencent.com/cms/audio/package)并调整好对应的业务配置。<br>

        ### 功能使用说明：
        - 前往“[内容安全控制台-音频内容安全](https://console.cloud.tencent.com/cms/audio/package)”开启使用音频内容安全服务，首次开通可获得**10小时**免费调用时长，有效期为1个月。
        - 默认接口请求频率限制：**20次/秒**；对于异步审核任务（点播音频），超出频率限制的请求会自动排入待审核队列，对于同步审核任务（直播音频），超出频率限制将会报错。

        ### 接口功能说明：
        - 支持对音频流或音频文件进行检测，判断其中是否包含违规内容；
        - 支持设置回调地址 Callback 获取检测结果（对于已在审核的任务，最长回调时间为用户配置的**切片时长 + 2s**），或通过接口(查询音频检测结果)主动轮询获取检测结果；
        - 支持识别违规内容，包括：低俗、谩骂、色情、广告等场景；
        - 支持批量提交检测任务，检测任务列表**最多支持10个**。

        ### 音频文件调用说明：
        - 音频文件大小支持：**文件 < 500M**；
        - 音频文件时长支持：**< 1小时**；
        - 音频码率类型支持：128 Kbps - 256 Kbps ；
        - 音频文件支持格式：wav、mp3、aac、flac、amr、3gp、 m4a、wma、ogg、ape；
        - （**当输入为视频文件时**）支持分离视频文件音轨，并对音频内容进行独立审核。

        ### 音频流调用说明：
        - 音频流时长支持：**< 3小时**；
        - 音频码率类型支持：128 Kbps - 256 Kbps ；
        - 音频流支持的传输协议：RTMP、HTTP、HTTPS；
        - 音频流格式支持的类型：rtp、srtp、rtmp、rtmps、mmsh、 mmst、hls、http、tcp、https、m3u8；
        - （**当输入为视频流时**）支持提取视频流音轨，并对音频内容进行独立审核。

        :param request: Request instance for CreateAudioModerationTask.
        :type request: :class:`tencentcloud.ams.v20201229.models.CreateAudioModerationTaskRequest`
        :rtype: :class:`tencentcloud.ams.v20201229.models.CreateAudioModerationTaskResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateAudioModerationTask", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateAudioModerationTaskResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTaskDetail(self, request):
        """通过该接口可查看音频审核任务的详情信息，包括任务状态、检测结果、音频文件识别出的对应文本内容、检测结果所对应的恶意标签及推荐的后续操作等，具体输出内容可查看输出参数示例。<br>默认接口请求频率限制：**100次/秒**。

        :param request: Request instance for DescribeTaskDetail.
        :type request: :class:`tencentcloud.ams.v20201229.models.DescribeTaskDetailRequest`
        :rtype: :class:`tencentcloud.ams.v20201229.models.DescribeTaskDetailResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeTaskDetail", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTaskDetailResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTasks(self, request):
        """通过该接口可查看审核任务列表；您也可根据多种业务信息（业务类型、审核结果、任务状态等）筛选审核任务列表。任务列表输出内容包括当前查询的任务总量、任务名称、任务状态、音频审核类型、基于检测结果的恶意标签及其后续操作等，具体输出内容可查看输出参数示例。<br>默认接口请求频率限制：**20次/秒**。

        :param request: Request instance for DescribeTasks.
        :type request: :class:`tencentcloud.ams.v20201229.models.DescribeTasksRequest`
        :rtype: :class:`tencentcloud.ams.v20201229.models.DescribeTasksResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeTasks", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTasksResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
DRYRUNOPERATION = 'DryRunOperation'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 实名认证失败。
FAILEDOPERATION_ACCOUNTVERIFYFAIL = 'FailedOperation.AccountVerifyFail'

# 年龄限制无法使用电子签服务，请联系客服咨询处理。
FAILEDOPERATION_AGENOTACHIEVENORMALLEGAL = 'FailedOperation.AgeNotAchieveNormalLegal'

# 签署流程已有关联文档，请检查参数修改后重试。
FAILEDOPERATION_FLOWHASDOCUMENT = 'FailedOperation.FlowHasDocument'

# 流程未找到关联的电子文件信息，请检查操作步骤，检查参数，并在修改后重试。
FAILEDOPERATION_FLOWHASNODOCUMENT = 'FailedOperation.FlowHasNoDocument'

# 签署审核未通过，请先完成审核。
FAILEDOPERATION_NOSIGNREVIEWPASS = 'FailedOperation.NoSignReviewPass'

# 企业经营状态与工商局信息不符。
FAILEDOPERATION_ORGANIZATIONEXPERIENCECHANGE = 'FailedOperation.OrganizationExperienceChange'

# 企业名称与工商局信息不符。
FAILEDOPERATION_ORGANIZATIONNAMECHANGED = 'FailedOperation.OrganizationNameChanged'

# 企业名称与工商局信息不符,需要超管修改。
FAILEDOPERATION_ORGANIZATIONNAMENEEDCHANGE = 'FailedOperation.OrganizationNameNeedChange'

# 创建签署流程预览链接失败，请稍后重试。
FAILEDOPERATION_PREVIEWURLFAIL = 'FailedOperation.PreViewUrlFail'

# 签署二维码模板发起方签署人存在签署控件，请检查模板后重试。
FAILEDOPERATION_QRCODECREATORSIGNCOMPONENTS = 'FailedOperation.QrCodeCreatorSignComponents'

# 签署二维码模板签署人不存在，请检查模板后重试。
FAILEDOPERATION_QRCODESIGNUSERS = 'FailedOperation.QrCodeSignUsers'

# 一码多人二维码模板有误。
FAILEDOPERATION_QRCODETEMPLATEID = 'FailedOperation.QrCodeTemplateId'

# 请求的次数超过了频率限制，请联系客服处理。
FAILEDOPERATION_REQUESTLIMITEXCEEDED = 'FailedOperation.RequestLimitExceeded'

# 模板无资源信息。
FAILEDOPERATION_TEMPLATEHASNORESOURCE = 'FailedOperation.TemplateHasNoResource'

# 用户信息不匹配，请检查后重试。
FAILEDOPERATION_USERINFONOMATCH = 'FailedOperation.UserInfoNoMatch'

# 内部错误。
INTERNALERROR = 'InternalError'

# 缓存错误。
INTERNALERROR_CACHE = 'InternalError.Cache'

# 数据库异常。
INTERNALERROR_DB = 'InternalError.Db'

# 数据库新增记录出错。
INTERNALERROR_DBINSERT = 'InternalError.DbInsert'

# 内部错误,数据库查询失败,请稍后重试。
INTERNALERROR_DBREAD = 'InternalError.DbRead'

# 解密失败。
INTERNALERROR_DECRYPTION = 'InternalError.Decryption'

# 依赖的第三方API返回错误。
INTERNALERROR_DEPENDSAPI = 'InternalError.DependsApi'

# 数据库执行错误。
INTERNALERROR_DEPENDSDB = 'InternalError.DependsDb'

# 加密失败。
INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'

# Pdf错误。
INTERNALERROR_PDF = 'InternalError.Pdf'

# 系统错误，请稍后重试。
INTERNALERROR_SYSTEM = 'InternalError.System'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 不合法的签署人类型，请检查后重试。
INVALIDPARAMETER_APPROVERTYPE = 'InvalidParameter.ApproverType'

# 不合法的业务id，请检查是否传递，检查是否超过接口上限数量，并在修改后重试。
INVALIDPARAMETER_BUSINESSID = 'InvalidParameter.BusinessId'

# 不合法的业务类型，请检查后重试。
INVALIDPARAMETER_BUSINESSTYPE = 'InvalidParameter.BusinessType'

# 不合法的撤销取消理由，将检查长度，内容，并在修改后重试。
INVALIDPARAMETER_CANCELREASON = 'InvalidParameter.CancelReason'

# 不合法的证件信息，请检查证件号证件类型是否正确。
INVALIDPARAMETER_CARDNUMBER = 'InvalidParameter.CardNumber'

# 不合法的证件信息，请检查证件号证件类型是否正确。
INVALIDPARAMETER_CARDTYPE = 'InvalidParameter.CardType'

# 不合法的抄送方设置，请联系客服了解抄送设置规则，修改后重试。
INVALIDPARAMETER_CCNUM = 'InvalidParameter.CcNum'

# ClientToken不合法请检查。
INVALIDPARAMETER_CLIENTTOKEN = 'InvalidParameter.ClientToken'

# 不合法的控件所在文件序号，请检查文件资源与控件的对应关系，并在修改后重试。
INVALIDPARAMETER_COMPONENTFILEINDEX = 'InvalidParameter.ComponentFileIndex'

# 不合法的控件页码，请与文件资源检查，并在修改后重试。
INVALIDPARAMETER_COMPONENTPAGE = 'InvalidParameter.ComponentPage'

# 不合法的控件大小或坐标，请检查控件坐标，大小是否合理，并在修改后重试。
INVALIDPARAMETER_COMPONENTPOSITION = 'InvalidParameter.ComponentPosition'

# 控件的类型与输入值不匹配，请检查参数修改后重试。
INVALIDPARAMETER_COMPONENTTYPENOMATCHVALUE = 'InvalidParameter.ComponentTypeNoMatchValue'

# 不合法的控件内容，请检查控件是否必填，检查控件内容是否正确设置，并在修改后重试。
INVALIDPARAMETER_COMPONENTVALUE = 'InvalidParameter.ComponentValue'

# 不合法的模板查询类型，请检查后重试。
INVALIDPARAMETER_CONTENTTYPE = 'InvalidParameter.ContentType'

# 数据已存在。
INVALIDPARAMETER_DATAEXISTS = 'InvalidParameter.DataExists'

# 数据不存在。
INVALIDPARAMETER_DATANOTFOUND = 'InvalidParameter.DataNotFound'

# 参数为空，请检查参数修改后重试。
INVALIDPARAMETER_EMPTYPARAMS = 'InvalidParameter.EmptyParams'

# 不合法的EndPoint，请检查修改后重试。
INVALIDPARAMETER_ENDPOINT = 'InvalidParameter.EndPoint'

# 不合法的签署流程回调链接，请修改后重试。
INVALIDPARAMETER_FLOWCALLBACKURL = 'InvalidParameter.FlowCallbackUrl'

# 不合法的签署流程截止日期，请修改后重试。
INVALIDPARAMETER_FLOWDEADLINE = 'InvalidParameter.FlowDeadLine'

# 不合法的签署流程描述，请修改后重试。
INVALIDPARAMETER_FLOWDESCRIPTION = 'InvalidParameter.FlowDescription'

# 不合法的签署流程名称，请修改后重试。
INVALIDPARAMETER_FLOWNAME = 'InvalidParameter.FlowName'

# 不合法的签署流程类型，请修改后重试。
INVALIDPARAMETER_FLOWTYPE = 'InvalidParameter.FlowType'

# 不合法的签署流程用户自定义数据，请修改后重试。
INVALIDPARAMETER_FLOWUSERDATA = 'InvalidParameter.FlowUserData'

# 不合法的FromSource，请联系开发，检查后重试。
INVALIDPARAMETER_FROMSOURCE = 'InvalidParameter.FromSource'

# 用户个人证件已过期。
INVALIDPARAMETER_IDCARDVALIDITYOVERLIMIT = 'InvalidParameter.IdCardValidityOverLimit'

# Channel不正确。
INVALIDPARAMETER_INVALIDCHANNEL = 'InvalidParameter.InvalidChannel'

# id类型参数不合法，请检查后重试。
INVALIDPARAMETER_INVALIDID = 'InvalidParameter.InvalidId'

# 参数Limit不正确。
INVALIDPARAMETER_INVALIDLIMIT = 'InvalidParameter.InvalidLimit'

# 手机号码不正确。
INVALIDPARAMETER_INVALIDMOBILE = 'InvalidParameter.InvalidMobile'

# 姓名不正确。
INVALIDPARAMETER_INVALIDNAME = 'InvalidParameter.InvalidName'

# 参数Offset不正确。
INVALIDPARAMETER_INVALIDOFFSET = 'InvalidParameter.InvalidOffset'

# OpenId不正确。
INVALIDPARAMETER_INVALIDOPENID = 'InvalidParameter.InvalidOpenId'

# 操作人ID不正确。
INVALIDPARAMETER_INVALIDOPERATORID = 'InvalidParameter.InvalidOperatorId'

# 机构ID不正确。
INVALIDPARAMETER_INVALIDORGANIZATIONID = 'InvalidParameter.InvalidOrganizationId'

# 组织机构名称不正确。
INVALIDPARAMETER_INVALIDORGANIZATIONNAME = 'InvalidParameter.InvalidOrganizationName'

# 角色ID不正确。
INVALIDPARAMETER_INVALIDROLEID = 'InvalidParameter.InvalidRoleId'

# 角色名称不正确。
INVALIDPARAMETER_INVALIDROLENAME = 'InvalidParameter.InvalidRoleName'

# 实名认证渠道不正确。
INVALIDPARAMETER_INVALIDVERIFYCHANNEL = 'InvalidParameter.InvalidVerifyChannel'

# 验证码不正确。
INVALIDPARAMETER_INVALIDVERIFYCODE = 'InvalidParameter.InvalidVerifyCode'

# 缺少必填控件的值。
INVALIDPARAMETER_MISSINGREQUIREDCOMPONENTVALUE = 'InvalidParameter.MissingRequiredComponentValue'

# 不合法的手机号，请检查后重试。
INVALIDPARAMETER_MOBILE = 'InvalidParameter.Mobile'

# 不合法的用户名称，请修改后重试。
INVALIDPARAMETER_NAME = 'InvalidParameter.Name'

# 不支持的通知类型，请检查并联系客服处理。
INVALIDPARAMETER_NOTIFYTYPE = 'InvalidParameter.NotifyType'

# 不合法的企业名称，请修改后重试。
INVALIDPARAMETER_ORGANIZATIONNAME = 'InvalidParameter.OrganizationName'

# 参数错误。
INVALIDPARAMETER_PARAMERROR = 'InvalidParameter.ParamError'

# 个人静默签Tag未设置，请检查后重试。
INVALIDPARAMETER_PERSONAUTOSIGNTAG = 'InvalidParameter.PersonAutoSignTag'

# 不合法的阅读时长限制，请联系客服了解阅读时长设置规则，修改后重试。
INVALIDPARAMETER_PREREADTIME = 'InvalidParameter.PreReadTime'

# 签署二维码的有效期不合法，请联系客服了解规则，并修稿后重试。
INVALIDPARAMETER_QREFFECTDAY = 'InvalidParameter.QrEffectDay'

# 二维码合同的有效期不合法，请联系客服了解规则，并修稿后重试。
INVALIDPARAMETER_QRFLOWEFFECTDAY = 'InvalidParameter.QrFlowEffectDay'

# 不合法的资源类型，请联系客服了解，并在修改后重试。
INVALIDPARAMETER_RESOURCETYPE = 'InvalidParameter.ResourceType'

# 不合法的印章id，请检查印章id是够正确，并在修改后重试。
INVALIDPARAMETER_SEALID = 'InvalidParameter.SealId'

# 参数Status不正确。
INVALIDPARAMETER_STATUS = 'InvalidParameter.Status'

# 不合法的签署二维码模板id，请检查修改后重试。
INVALIDPARAMETER_TEMPLATEID = 'InvalidParameter.TemplateId'

# 不合法的认证渠道，请联系客户了解电子签支持的认证渠道，并在修改后重试。
INVALIDPARAMETER_VERIFYCHANNEL = 'InvalidParameter.VerifyChannel'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 需要屏蔽的告警。
INVALIDPARAMETERVALUE_MASK = 'InvalidParameterValue.Mask'

# 超过配额限制。
LIMITEXCEEDED = 'LimitExceeded'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 缺少签署人手机号，请检查后重试。
MISSINGPARAMETER_APPROVERMOBILE = 'MissingParameter.ApproverMobile'

# 缺少签署人姓名，请检查后重试。
MISSINGPARAMETER_APPROVERNAME = 'MissingParameter.ApproverName'

# 缺少签署人企业信息，请检查后重试。
MISSINGPARAMETER_APPROVERORGANIZATIONINFO = 'MissingParameter.ApproverOrganizationInfo'

# 缺少签署流程签署人角色信息，请检查修改后重试。
MISSINGPARAMETER_APPROVERROLE = 'MissingParameter.ApproverRole'

# 缺少签署人签署控件配置，请联系客服了解控件传递规则，并在修改后重试。
MISSINGPARAMETER_APPROVERSIGNCOMPONENT = 'MissingParameter.ApproverSignComponent'

# 授权码为空，请检查后重试。
MISSINGPARAMETER_AUTHCODE = 'MissingParameter.AuthCode'

# 缺少撤销取消理由，请检查修改后重试。
MISSINGPARAMETER_CANCELREASON = 'MissingParameter.CancelReason'

# 未找到表单域配置信息，请检查控件传参，检查文件资源配置，并在修改后重试。
MISSINGPARAMETER_FIELD = 'MissingParameter.Field'

# 文件名为空，请检查参数修改后重试。
MISSINGPARAMETER_FILENAMES = 'MissingParameter.FileNames'

# 缺少签署流程签署人信息，请指定签署人信息后重试。
MISSINGPARAMETER_FLOWAPPROVER = 'MissingParameter.FlowApprover'

# 缺少签署流程id，请检查修改后重试。
MISSINGPARAMETER_FLOWID = 'MissingParameter.FlowId'

# 未找到关键字配置信息，请检查控件传参，检查文件资源配置，并在修改后重试。
MISSINGPARAMETER_KEYWORD = 'MissingParameter.KeyWord'

# 缺少签署二维码id，请检查后重试。
MISSINGPARAMETER_QRCODEID = 'MissingParameter.QrCodeId'

# 缺少模板签署人信息，请检查后重试。
MISSINGPARAMETER_RECIPIENT = 'MissingParameter.Recipient'

# 缺少文件资源ID，请检查后重试。
MISSINGPARAMETER_RESOURCEID = 'MissingParameter.ResourceId'

# 缺少资源名称，请检查修改后重试。
MISSINGPARAMETER_RESOURCENAME = 'MissingParameter.ResourceName'

# 缺少静默签印章id，请检查修改后重试。
MISSINGPARAMETER_SERVERSIGNSEALID = 'MissingParameter.ServerSignSealId'

# 缺少签署控件参数。
MISSINGPARAMETER_SIGNCOMPONENTS = 'MissingParameter.SignComponents'

# 缺少用户id，请检查后重试。
MISSINGPARAMETER_USERID = 'MissingParameter.UserId'

# 操作被拒绝。
OPERATIONDENIED = 'OperationDenied'

# 签署人设置与模板中签署人配置信息不一致，请检查模板修改参数后重试。
OPERATIONDENIED_APPROVERNOMATCHTEMPLATE = 'OperationDenied.ApproverNoMatchTemplate'

# 签署人重复，请联系客服了解发起签署流程签署人规则，修改后重试。
OPERATIONDENIED_APPROVERREPEAT = 'OperationDenied.ApproverRepeat'

# 授权码已失效，请检查是否传递正确，是否已经过期，并在修改后重试。
OPERATIONDENIED_AUTHCODEINVALID = 'OperationDenied.AuthCodeInvalid'

# 不允许批量撤销签署流程，请检查批量撤销合同信息。
OPERATIONDENIED_BATCHCANCELFORBID = 'OperationDenied.BatchCancelForbid'

# 子公司不能发起本方母体公司的合同。
OPERATIONDENIED_BRANCHSENDFLOWTOPARENTNOTALLOW = 'OperationDenied.BranchSendFlowToParentNotAllow'

# 当前不支持抄送，请联系客服咨询处理。
OPERATIONDENIED_CCFORBID = 'OperationDenied.CcForbid'

# 抄送方存在相同抄送人，请检查修改后重试。
OPERATIONDENIED_CCUSERREPEAT = 'OperationDenied.CcUserRepeat'

# 电子文档不可用，请稍后重试。
OPERATIONDENIED_DOCUMENTNOAVAILABLE = 'OperationDenied.DocumentNoAvailable'

# 此企业无该资源使用权限。
OPERATIONDENIED_ERRNORESOURCEACCESS = 'OperationDenied.ErrNoResourceAccess'

# 个人签署方不支持设置企业名称，请确认签署人类型后重试。
OPERATIONDENIED_ERRNOSUPPORTINDIVIDUALHASORGANIZATIONNAME = 'OperationDenied.ErrNoSupportIndividualHasOrganizationName'

# 文件与资源不匹配，请检查文件名与资源id数量以及对应关系，并在修改后重试。
OPERATIONDENIED_FILENOMATCHRESOURCE = 'OperationDenied.FileNoMatchResource'

# 签署流程无法撤销，请检查签署流程状态，检查签署流程归属企业，检查当前操作人是否有权限，并在修改后重试。
OPERATIONDENIED_FLOWCANCELFORBID = 'OperationDenied.FlowCancelForbid'

# 签署流程已经被发起，请检查。
OPERATIONDENIED_FLOWHASSTARTED = 'OperationDenied.FlowHasStarted'

# 签署流程已经被终止，请检查。
OPERATIONDENIED_FLOWHASTERMINATED = 'OperationDenied.FlowHasTerminated'

# 签署流程不需要进行审核,请修改后重试。
OPERATIONDENIED_FLOWNONEEDREVIEW = 'OperationDenied.FlowNoNeedReview'

# 签署流程状态不正确，请检查后重试。
OPERATIONDENIED_FLOWSTATUSFORBID = 'OperationDenied.FlowStatusForbid'

# 禁止此项操作。
OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'

# 签署人年龄限制无法使用电子签服务。
OPERATIONDENIED_INVALIDAPPROVERAGE = 'OperationDenied.InvalidApproverAge'

# 资源id超过使用上限限制，请联系客服了解规则，并在修改后重试。
OPERATIONDENIED_MANYRESOURCEID = 'OperationDenied.ManyResourceId'

# 无权限操作签署流程，请联系客服了解权限，并在修改后重试。
OPERATIONDENIED_NOFLOWPERMISSION = 'OperationDenied.NoFlowPermission'

# 未通过个人实名认证。
OPERATIONDENIED_NOIDENTITYVERIFY = 'OperationDenied.NoIdentityVerify'

# 用户未登录,请先登录后再操作。
OPERATIONDENIED_NOLOGIN = 'OperationDenied.NoLogin'

# 未开通静默签功能，请联系签署方企业开通后重试。
OPERATIONDENIED_NOOPENSERVERSIGN = 'OperationDenied.NoOpenServerSign'

# 无权限使用文件资源，请检查资源有效性以及资源归属，并在修改后重试。
OPERATIONDENIED_NOPERMISSIONUSERESOURCE = 'OperationDenied.NoPermissionUseResource'

# 无权限使用印章做静默签，请检查印章是否有效，是否有使用权限，并在修改后重试。
OPERATIONDENIED_NOPERMISSIONUSESERVERSIGNSEAL = 'OperationDenied.NoPermissionUseServerSignSeal'

# 企业额度不足，请检查企业额度后处理。
OPERATIONDENIED_NOQUOTA = 'OperationDenied.NoQuota'

# 不支持的控件类型，请联系客服了解支持的控件类型，并在修改后重试。
OPERATIONDENIED_NOSUPPORTCOMPONENTTYPE = 'OperationDenied.NoSupportComponentType'

# 不支持的跳转页，请联系客服了解跳转配置规则，修改后重试。
OPERATIONDENIED_NOSUPPORTJUMPPAGE = 'OperationDenied.NoSupportJumpPage'

# 未完成实名认证，请检查后重试。
OPERATIONDENIED_NOVERIFY = 'OperationDenied.NoVerify'

# 不属于企业超管或者法人。
OPERATIONDENIED_NOTBELONGSUPERADMINORLEGALPERSON = 'OperationDenied.NotBelongSuperAdminOrLegalPerson'

# 此社会信用编码未查询到结果，请检查后重试。
OPERATIONDENIED_ORGUNIFORMSOCIALCREDITCODEERR = 'OperationDenied.OrgUniformSocialCreditCodeErr'

# 企业未激活。
OPERATIONDENIED_ORGANIZATIONNOTACTIVATED = 'OperationDenied.OrganizationNotActivated'

# 查询限频，请先联系客服了解限频策略，稍后重试。
OPERATIONDENIED_OUTQUERYLIMIT = 'OperationDenied.OutQueryLimit'

# 当前不支持境外用户，请联系客服咨询处理。
OPERATIONDENIED_OVERSEAFORBID = 'OperationDenied.OverSeaForbid'

# 个人名下没用可使用的签名，请联系个人配置签名后重试。
OPERATIONDENIED_PERSONHASNOSIGNATURE = 'OperationDenied.PersonHasNoSignature'

# 该用户已关闭或者未开启自动签服务，请检查后重试。
OPERATIONDENIED_PERSONNOOPENSERVERSIGN = 'OperationDenied.PersonNoOpenServerSign'

# 拒绝个人静默签，请检查个人静默签签署人，并在修改后重试。
OPERATIONDENIED_PERSONSERVERSIGNFORBID = 'OperationDenied.PersonServerSignForbid'

# 签署二维码已过期，请检查后重试。
OPERATIONDENIED_QRHASEXPIRE = 'OperationDenied.QrHasExpire'

# 签署二维码不可用，请检查后重试。
OPERATIONDENIED_QRINVALID = 'OperationDenied.QrInvalid'

# 必填控件未设置填写内容，将检查修改后重试。
OPERATIONDENIED_REQUIREDCOMPONENTNOTFILL = 'OperationDenied.RequiredComponentNotFill'

# 静默签署方不允许有填写控件，请修改模板，修改参数后重试。
OPERATIONDENIED_SERVERSIGNNOALLOWCOMPONENT = 'OperationDenied.ServerSignNoAllowComponent'

# 静默签署不支持手写签名，请配置印章并使用印章重试。
OPERATIONDENIED_SERVERSIGNNOSUPPORTSIGNATURE = 'OperationDenied.ServerSignNoSupportSignature'

# 用户不归属于当前企业，无法操作，请检查后重试。
OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'

# 未开通功能白名单，请联系客服处理。
OPERATIONDENIED_WHITELISTFORBID = 'OperationDenied.WhiteListForbid'

# 请求的次数超过了频率限制。
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# 资源被占用。
RESOURCEINUSE = 'ResourceInUse'

# 资源不足。
RESOURCEINSUFFICIENT = 'ResourceInsufficient'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# 应用号不存在或已删除。
RESOURCENOTFOUND_APPLICATION = 'ResourceNotFound.Application'

# 机构未完成认证激活，请检查并联系客服处理。
RESOURCENOTFOUND_AUTHACTIVEORGANIZATION = 'ResourceNotFound.AuthActiveOrganization'

# 未找到电子文档信息，请检查后重试。
RESOURCENOTFOUND_DOCUMENT = 'ResourceNotFound.Document'

# 未获取到用户角色信息，请检查员工角色配置。
RESOURCENOTFOUND_ERRNOTEXISTROLE = 'ResourceNotFound.ErrNotExistRole'

# 签署流程未找到，请检查参数。
RESOURCENOTFOUND_FLOW = 'ResourceNotFound.Flow'

# 签署流程的签署人不存在，请检查后重试。
RESOURCENOTFOUND_FLOWAPPROVER = 'ResourceNotFound.FlowApprover'

# 电子文档不存在。
RESOURCENOTFOUND_NOTEXISTDOCUMENT = 'ResourceNotFound.NotExistDocument'

# 流程不存在。
RESOURCENOTFOUND_NOTEXISTFLOW = 'ResourceNotFound.NotExistFlow'

# 指定的资源不存在。
RESOURCENOTFOUND_NOTEXISTRESOURCE = 'ResourceNotFound.NotExistResource'

# 模板不存在。
RESOURCENOTFOUND_NOTEXISTTEMPLATE = 'ResourceNotFound.NotExistTemplate'

# 机构不存在或者未完成认证，请检查机构信息。
RESOURCENOTFOUND_ORGANIZATION = 'ResourceNotFound.Organization'

# 签署二维码信息不存在，请检查后重试。
RESOURCENOTFOUND_QRINFO = 'ResourceNotFound.QrInfo'

# 未获取到文件资源，请检查资源是否完成上传，是否有效，并在修改后重试。
RESOURCENOTFOUND_RESOURCE = 'ResourceNotFound.Resource'

# 超管信息不存在，请检查企业认证信息。
RESOURCENOTFOUND_SUPERADMIN = 'ResourceNotFound.SuperAdmin'

# 模板不存在，请检查模板参数，模板配置，并稍后重试。
RESOURCENOTFOUND_TEMPLATE = 'ResourceNotFound.Template'

# Url不存在。
RESOURCENOTFOUND_URL = 'ResourceNotFound.Url'

# 用户或者员工信息不存在，请检查参数后重试。
RESOURCENOTFOUND_USER = 'ResourceNotFound.User'

# 用户或者员工未完成实名认证，请检查参数后重试。
RESOURCENOTFOUND_VERIFYUSER = 'ResourceNotFound.VerifyUser'

# 资源不可用。
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# 未知参数错误。
UNKNOWNPARAMETER = 'UnknownParameter'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class BindOrganizationMemberAuthAccountRequest(AbstractModel):
    """BindOrganizationMemberAuthAccount请求参数结构体

    """

    def __init__(self):
        r"""
        :param MemberUin: 成员Uin。
        :type MemberUin: int
        :param PolicyId: 策略ID。
        :type PolicyId: int
        :param OrgSubAccountUins: 组织子账号Uin。
        :type OrgSubAccountUins: list of int
        """
        self.MemberUin = None
        self.PolicyId = None
        self.OrgSubAccountUins = None


    def _deserialize(self, params):
        self.MemberUin = params.get("MemberUin")
        self.PolicyId = params.get("PolicyId")
        self.OrgSubAccountUins = params.get("OrgSubAccountUins")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class BindOrganizationMemberAuthAccountResponse(AbstractModel):
    """BindOrganizationMemberAuthAccount返回参数结构体

    """

    def __init__(self):
        r"""
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreateOrganizationMemberPolicyRequest(AbstractModel):
    """CreateOrganizationMemberPolicy请求参数结构体

    """

    def __init__(self):
        r"""
        :param MemberUin: 成员Uin。
        :type MemberUin: int
        :param PolicyName: 策略名。
        :type PolicyName: str
        :param IdentityId: 身份ID。
        :type IdentityId: int
        :param Description: 描述。
        :type Description: str
        """
        self.MemberUin = None
        self.PolicyName = None
        self.IdentityId = None
        self.Description = None


    def _deserialize(self, params):
        self.MemberUin = params.get("MemberUin")
        self.PolicyName = params.get("PolicyName")
        self.IdentityId = params.get("IdentityId")
        self.Description = params.get("Description")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateOrganizationMemberPolicyResponse(AbstractModel):
    """CreateOrganizationMemberPolicy返回参数结构体

    """

    def __init__(self):
        r"""
        :param PolicyId: 策略ID。
注意：此字段可能返回 null，表示取不到有效值。
        :type PolicyId: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.PolicyId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.PolicyId = params.get("PolicyId")
        self.RequestId = params.get("RequestId")


class CreateOrganizationMemberRequest(AbstractModel):
    """CreateOrganizationMember请求参数结构体

    """

    def __init__(self):
        r"""
        :param Name: 名称
        :type Name: str
        :param PolicyType: 关系策略  取值：Financial
        :type PolicyType: str
        :param PermissionIds: 关系权限 取值：1-查看账单、2-查看余额、3-资金划拨、4-合并出账、5-开票 ，1、2 默认必须
        :type PermissionIds: list of int non-negative
        :param NodeId: 成员所属部门的节点ID
        :type NodeId: int
        :param AccountName: 账号名
        :type AccountName: str
        :param Remark: 备注
        :type Remark: str
        :param RecordId: 重试创建传记录ID
        :type RecordId: int
        :param PayUin: 代付者Uin
        :type PayUin: str
        :param IdentityRoleID: 管理身份
        :type IdentityRoleID: list of int non-negative
        """
        self.Name = None
        self.PolicyType = None
        self.PermissionIds = None
        self.NodeId = None
        self.AccountName = None
        self.Remark = None
        self.RecordId = None
        self.PayUin = None
        self.IdentityRoleID = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.PolicyType = params.get("PolicyType")
        self.PermissionIds = params.get("PermissionIds")
        self.NodeId = params.get("NodeId")
        self.AccountName = params.get("AccountName")
        self.Remark = params.get("Remark")
        self.RecordId = params.get("RecordId")
        self.PayUin = params.get("PayUin")
        self.IdentityRoleID = params.get("IdentityRoleID")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateOrganizationMemberResponse(AbstractModel):
    """CreateOrganizationMember返回参数结构体

    """

    def __init__(self):
        r"""
        :param Uin: 成员Uin
注意：此字段可能返回 null，表示取不到有效值。
        :type Uin: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Uin = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Uin = params.get("Uin")
        self.RequestId = params.get("RequestId")


class DescribeOrganizationMembersRequest(AbstractModel):
    """DescribeOrganizationMembers请求参数结构体

    """

    def __init__(self):
        r"""
        :param Offset: 偏移量
        :type Offset: int
        :param Limit: 限制数目
        :type Limit: int
        :param Lang: 国际站：en，国内站：zh
        :type Lang: str
        :param SearchKey: 成员名或者成员ID搜索
        :type SearchKey: str
        :param AuthName: 主体名称
        :type AuthName: str
        :param Product: 集团服务（服务管理员查询时，必须指定）
        :type Product: str
        """
        self.Offset = None
        self.Limit = None
        self.Lang = None
        self.SearchKey = None
        self.AuthName = None
        self.Product = None


    def _deserialize(self, params):
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        self.Lang = params.get("Lang")
        self.SearchKey = params.get("SearchKey")
        self.AuthName = params.get("AuthName")
        self.Product = params.get("Product")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeOrganizationMembersResponse(AbstractModel):
    """DescribeOrganizationMembers返回参数结构体

    """

    def __init__(self):
        r"""
        :param Items: 成员列表
        :type Items: list of OrgMember
        :param Total: 总数目
        :type Total: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Items = None
        self.Total = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Items") is not None:
            self.Items = []
            for item in params.get("Items"):
                obj = OrgMember()
                obj._deserialize(item)
                self.Items.append(obj)
        self.Total = params.get("Total")
        self.RequestId = params.get("RequestId")


class DescribeOrganizationRequest(AbstractModel):
    """DescribeOrganization请求参数结构体

    """

    def __init__(self):
        r"""
        :param Lang: 国际站：en，国内站：zh
        :type Lang: str
        :param Product: 产品简称（查询是否集团服务委派管理员必填）
        :type Product: str
        """
        self.Lang = None
        self.Product = None


    def _deserialize(self, params):
        self.Lang = params.get("Lang")
        self.Product = params.get("Product")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeOrganizationResponse(AbstractModel):
    """DescribeOrganization返回参数结构体

    """

    def __init__(self):
        r"""
        :param OrgId: 企业组织ID
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgId: int
        :param HostUin: 创建者UIN
注意：此字段可能返回 null，表示取不到有效值。
        :type HostUin: int
        :param NickName: 创建者昵称
注意：此字段可能返回 null，表示取不到有效值。
        :type NickName: str
        :param OrgType: 企业组织类型
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgType: int
        :param IsManager: 组织管理员：true，组织成员：false
注意：此字段可能返回 null，表示取不到有效值。
        :type IsManager: bool
        :param OrgPolicyType: 策略类型
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgPolicyType: str
        :param OrgPolicyName: 策略名
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgPolicyName: str
        :param OrgPermission: 策略权限
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgPermission: list of OrgPermission
        :param RootNodeId: 根节点ID
注意：此字段可能返回 null，表示取不到有效值。
        :type RootNodeId: int
        :param CreateTime: 创建时间
注意：此字段可能返回 null，表示取不到有效值。
        :type CreateTime: str
        :param JoinTime: 成员加入时间
注意：此字段可能返回 null，表示取不到有效值。
        :type JoinTime: str
        :param IsAllowQuit: 是否允许退出。允许：Allow，不允许：Denied。
注意：此字段可能返回 null，表示取不到有效值。
        :type IsAllowQuit: str
        :param PayUin: 代付者Uin
注意：此字段可能返回 null，表示取不到有效值。
        :type PayUin: str
        :param PayName: 代付者名称
注意：此字段可能返回 null，表示取不到有效值。
        :type PayName: str
        :param IsAssignManager: 是否集团服务委派管理员 true-是、false-否
注意：此字段可能返回 null，表示取不到有效值。
        :type IsAssignManager: bool
        :param IsAuthManager: 是否主体管理员 true-是、false-否
注意：此字段可能返回 null，表示取不到有效值。
        :type IsAuthManager: bool
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.OrgId = None
        self.HostUin = None
        self.NickName = None
        self.OrgType = None
        self.IsManager = None
        self.OrgPolicyType = None
        self.OrgPolicyName = None
        self.OrgPermission = None
        self.RootNodeId = None
        self.CreateTime = None
        self.JoinTime = None
        self.IsAllowQuit = None
        self.PayUin = None
        self.PayName = None
        self.IsAssignManager = None
        self.IsAuthManager = None
        self.RequestId = None


    def _deserialize(self, params):
        self.OrgId = params.get("OrgId")
        self.HostUin = params.get("HostUin")
        self.NickName = params.get("NickName")
        self.OrgType = params.get("OrgType")
        self.IsManager = params.get("IsManager")
        self.OrgPolicyType = params.get("OrgPolicyType")
        self.OrgPolicyName = params.get("OrgPolicyName")
        if params.get("OrgPermission") is not None:
            self.OrgPermission = []
            for item in params.get("OrgPermission"):
                obj = OrgPermission()
                obj._deserialize(item)
                self.OrgPermission.append(obj)
        self.RootNodeId = params.get("RootNodeId")
        self.CreateTime = params.get("CreateTime")
        self.JoinTime = params.get("JoinTime")
        self.IsAllowQuit = params.get("IsAllowQuit")
        self.PayUin = params.get("PayUin")
        self.PayName = params.get("PayName")
        self.IsAssignManager = params.get("IsAssignManager")
        self.IsAuthManager = params.get("IsAuthManager")
        self.RequestId = params.get("RequestId")


class MemberIdentity(AbstractModel):
    """成员管理身份

    """

    def __init__(self):
        r"""
        :param IdentityId: 身份ID。
注意：此字段可能返回 null，表示取不到有效值。
        :type IdentityId: int
        :param IdentityAliasName: 身份名称。
注意：此字段可能返回 null，表示取不到有效值。
        :type IdentityAliasName: str
        """
        self.IdentityId = None
        self.IdentityAliasName = None


    def _deserialize(self, params):
        self.IdentityId = params.get("IdentityId")
        self.IdentityAliasName = params.get("IdentityAliasName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OrgMember(AbstractModel):
    """企业组织成员

    """

    def __init__(self):
        r"""
        :param MemberUin: 成员Uin
注意：此字段可能返回 null，表示取不到有效值。
        :type MemberUin: int
        :param Name: 成员名
注意：此字段可能返回 null，表示取不到有效值。
        :type Name: str
        :param MemberType: 成员类型，邀请：Invite， 创建：Create
注意：此字段可能返回 null，表示取不到有效值。
        :type MemberType: str
        :param OrgPolicyType: 关系策略类型
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgPolicyType: str
        :param OrgPolicyName: 关系策略名
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgPolicyName: str
        :param OrgPermission: 关系策略权限
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgPermission: list of OrgPermission
        :param NodeId: 所属节点ID
注意：此字段可能返回 null，表示取不到有效值。
        :type NodeId: int
        :param NodeName: 所属节点名
注意：此字段可能返回 null，表示取不到有效值。
        :type NodeName: str
        :param Remark: 备注
注意：此字段可能返回 null，表示取不到有效值。
        :type Remark: str
        :param CreateTime: 创建时间
注意：此字段可能返回 null，表示取不到有效值。
        :type CreateTime: str
        :param UpdateTime: 更新时间
注意：此字段可能返回 null，表示取不到有效值。
        :type UpdateTime: str
        :param IsAllowQuit: 是否允许成员退出。允许：Allow，不允许：Denied。
注意：此字段可能返回 null，表示取不到有效值。
        :type IsAllowQuit: str
        :param PayUin: 代付者Uin
注意：此字段可能返回 null，表示取不到有效值。
        :type PayUin: str
        :param PayName: 代付者名称
注意：此字段可能返回 null，表示取不到有效值。
        :type PayName: str
        :param OrgIdentity: 管理身份
注意：此字段可能返回 null，表示取不到有效值。
        :type OrgIdentity: list of MemberIdentity
        :param BindStatus: 安全信息绑定状态  未绑定：Unbound，待激活：Valid，绑定成功：Success，绑定失败：Failed
注意：此字段可能返回 null，表示取不到有效值。
        :type BindStatus: str
        :param PermissionStatus: 成员权限状态 已确认：Confirmed ，待确认：UnConfirmed
注意：此字段可能返回 null，表示取不到有效值。
        :type PermissionStatus: str
        """
        self.MemberUin = None
        self.Name = None
        self.MemberType = None
        self.OrgPolicyType = None
        self.OrgPolicyName = None
        self.OrgPermission = None
        self.NodeId = None
        self.NodeName = None
        self.Remark = None
        self.CreateTime = None
        self.UpdateTime = None
        self.IsAllowQuit = None
        self.PayUin = None
        self.PayName = None
        self.OrgIdentity = None
        self.BindStatus = None
        self.PermissionStatus = None


    def _deserialize(self, params):
        self.MemberUin = params.get("MemberUin")
        self.Name = params.get("Name")
        self.MemberType = params.get("MemberType")
        self.OrgPolicyType = params.get("OrgPolicyType")
        self.OrgPolicyName = params.get("OrgPolicyName")
        if params.get("OrgPermission") is not None:
            self.OrgPermission = []
            for item in params.get("OrgPermission"):
                obj = OrgPermission()
                obj._deserialize(item)
                self.OrgPermission.append(obj)
        self.NodeId = params.get("NodeId")
        self.NodeName = params.get("NodeName")
        self.Remark = params.get("Remark")
        self.CreateTime = params.get("CreateTime")
        self.UpdateTime = params.get("UpdateTime")
        self.IsAllowQuit = params.get("IsAllowQuit")
        self.PayUin = params.get("PayUin")
        self.PayName = params.get("PayName")
        if params.get("OrgIdentity") is not None:
            self.OrgIdentity = []
            for item in params.get("OrgIdentity"):
                obj = MemberIdentity()
                obj._deserialize(item)
                self.OrgIdentity.append(obj)
        self.BindStatus = params.get("BindStatus")
        self.PermissionStatus = params.get("PermissionStatus")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class OrgPermission(AbstractModel):
    """关系策略权限

    """

    def __init__(self):
        r"""
        :param Id: 权限Id
        :type Id: int
        :param Name: 权限名
        :type Name: str
        """
        self.Id = None
        self.Name = None


    def _deserialize(self, params):
        self.Id = params.get("Id")
        self.Name = params.get("Name")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 认证失败。
AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'

# 余额不足，开通失败，请充值后再开通。
FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'

# 文件下载错误。
FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownloadError'

# 图片内容为空。
FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'

# 图片解码失败。
FAILEDOPERATION_IMAGEDECODEFAILED = 'FailedOperation.ImageDecodeFailed'

# 图片删除失败。
FAILEDOPERATION_IMAGEDELETEFAILED = 'FailedOperation.ImageDeleteFailed'

# 图片下载错误。
FAILEDOPERATION_IMAGEDOWNLOADERROR = 'FailedOperation.ImageDownloadError'

# 超出Entity数量限制。
FAILEDOPERATION_IMAGEENTITYCOUNTEXCEED = 'FailedOperation.ImageEntityCountExceed'

# 图库为空。
FAILEDOPERATION_IMAGEGROUPEMPTY = 'FailedOperation.ImageGroupEmpty'

# 未找到图片信息。
FAILEDOPERATION_IMAGENOTFOUNDINFO = 'FailedOperation.ImageNotFoundInfo'

# 不支持的图片文件。
FAILEDOPERATION_IMAGENOTSUPPORTED = 'FailedOperation.ImageNotSupported'

# 超出图库限制。
FAILEDOPERATION_IMAGENUMEXCEED = 'FailedOperation.ImageNumExceed'

# 图片分辨率过大。
FAILEDOPERATION_IMAGERESOLUTIONEXCEED = 'FailedOperation.ImageResolutionExceed'

# 未查询到结果。
FAILEDOPERATION_IMAGESEARCHINVALID = 'FailedOperation.ImageSearchInvalid'

# base64编码后的图片数据过大。
FAILEDOPERATION_IMAGESIZEEXCEED = 'FailedOperation.ImageSizeExceed'

# 图片不满足检测要求。
FAILEDOPERATION_IMAGEUNQUALIFIED = 'FailedOperation.ImageUnQualified'

# url地址不合法，无法下载。
FAILEDOPERATION_IMAGEURLINVALID = 'FailedOperation.ImageUrlInvalid'

# 内部错误。
FAILEDOPERATION_INNERERROR = 'FailedOperation.InnerError'

# 调用计费返回失败。
FAILEDOPERATION_INVOKECHARGEERROR = 'FailedOperation.InvokeChargeError'

# 参数为空。
FAILEDOPERATION_PARAMETEREMPTY = 'FailedOperation.ParameterEmpty'

# 车辆识别失败。
FAILEDOPERATION_RECOGNIZEFAILDED = 'FailedOperation.RecognizeFailded'

# 后端服务请求失败。
FAILEDOPERATION_REQUESTERROR = 'FailedOperation.RequestError'

# 后端服务超时。
FAILEDOPERATION_REQUESTTIMEOUT = 'FailedOperation.RequestTimeout'

# RPC请求失败，一般为算法微服务故障。
FAILEDOPERATION_RPCFAIL = 'FailedOperation.RpcFail'

# 算法服务异常，请重试。
FAILEDOPERATION_SERVERERROR = 'FailedOperation.ServerError'

# 文件太大。
FAILEDOPERATION_TOOLARGEFILEERROR = 'FailedOperation.TooLargeFileError'

# 内部错误。
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'

# 服务未开通。
FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'

# 未知错误。
FAILEDOPERATION_UNKNOWN = 'FailedOperation.Unknown'

# 不支持的图片格式。
INVALIDPARAMETER_IMAGEFORMATNOTSUPPORT = 'InvalidParameter.ImageFormatNotSupport'

# 参数取值错误。
INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'

# 图库简介过长。
INVALIDPARAMETERVALUE_BRIEFTOOLONG = 'InvalidParameterValue.BriefTooLong'

# 自定义内容过长。
INVALIDPARAMETERVALUE_CUSTOMCONTENTTOOLONG = 'InvalidParameterValue.CustomContentTooLong'

# 物品ID为空。
INVALIDPARAMETERVALUE_ENTITYIDEMPTY = 'InvalidParameterValue.EntityIdEmpty'

# 物品ID超出长度限制。
INVALIDPARAMETERVALUE_ENTITYIDTOOLONG = 'InvalidParameterValue.EntityIdTooLong'

# Filter参数不合法。
INVALIDPARAMETERVALUE_FILTERINVALID = 'InvalidParameterValue.FilterInvalid'

# Filter参数过长。
INVALIDPARAMETERVALUE_FILTERSIZEEXCEED = 'InvalidParameterValue.FilterSizeExceed'

# 图库ID已存在。
INVALIDPARAMETERVALUE_IMAGEGROUPIDALREADYEXIST = 'InvalidParameterValue.ImageGroupIdAlreadyExist'

# 图库ID不合法。
INVALIDPARAMETERVALUE_IMAGEGROUPIDILLEGAL = 'InvalidParameterValue.ImageGroupIdIllegal'

# 图库ID不存在。
INVALIDPARAMETERVALUE_IMAGEGROUPIDNOTEXIST = 'InvalidParameterValue.ImageGroupIdNotExist'

# 图库ID超出长度限制。
INVALIDPARAMETERVALUE_IMAGEGROUPIDTOOLONG = 'InvalidParameterValue.ImageGroupIdTooLong'

# 图库名称为空。
INVALIDPARAMETERVALUE_IMAGEGROUPNAMEEMPTY = 'InvalidParameterValue.ImageGroupNameEmpty'

# 图库名称超出长度限制。
INVALIDPARAMETERVALUE_IMAGEGROUPNAMETOOLONG = 'InvalidParameterValue.ImageGroupNameTooLong'

# 参数值错误。
INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'

# 返回数量不在合法范围内。
INVALIDPARAMETERVALUE_LIMITEXCEED = 'InvalidParameterValue.LimitExceed'

# 图片名称重复。
INVALIDPARAMETERVALUE_PICNAMEALREADYEXIST = 'InvalidParameterValue.PicNameAlreadyExist'

# 图片名称为空。
INVALIDPARAMETERVALUE_PICNAMEEMPTY = 'InvalidParameterValue.PicNameEmpty'

# 图片名称超出长度限制。
INVALIDPARAMETERVALUE_PICNAMETOOLONG = 'InvalidParameterValue.PicNameTooLong'

# 标签数量过多。
INVALIDPARAMETERVALUE_TAGSKEYSEXCEED = 'InvalidParameterValue.TagsKeysExceed'

# 标签值类型不合法。
INVALIDPARAMETERVALUE_TAGSVALUEILLEGAL = 'InvalidParameterValue.TagsValueIllegal'

# 标签值长度过长。
INVALIDPARAMETERVALUE_TAGSVALUESIZEEXCEED = 'InvalidParameterValue.TagsValueSizeExceed'

# URL格式不合法。
INVALIDPARAMETERVALUE_URLILLEGAL = 'InvalidParameterValue.UrlIllegal'

# 文件太大。
LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'

# 必选参数为空。
MISSINGPARAMETER_ERRORPARAMETEREMPTY = 'MissingParameter.ErrorParameterEmpty'

# 账号已欠费。
RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'

# 服务正在开通中，请稍等。
RESOURCEUNAVAILABLE_ISOPENING = 'ResourceUnavailable.IsOpening'

# 计费状态未知，请确认是否已在控制台开通服务。
RESOURCEUNAVAILABLE_NOTEXIST = 'ResourceUnavailable.NotExist'

# 计费状态异常。
RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 未支持的功能。
FAILEDOPERATION_NOTSUPPORTEDFUNCTIONERROR = 'FailedOperation.NotSupportedFunctionError'

# 内部错误
INTERNALERROR = 'InternalError'

# 任务已被强制取消
INTERNALERROR_JOBCANCELED = 'InternalError.JobCanceled'

# 任务失败重试次数超过上限
INTERNALERROR_JOBREACHMAXRETRYTIMES = 'InternalError.JobReachMaxRetryTimes'

# 查询人脸库失败
INTERNALERROR_STATUSQUERYFACELIBFAILED = 'InternalError.StatusQueryFaceLibFailed'

# 参数错误
INVALIDPARAMETER = 'InvalidParameter'

# 人体检索失败
INVALIDPARAMETER_BODYRETRIEVALFAILED = 'InvalidParameter.BodyRetrievalFailed'

# 无法检测到人脸，请确认输入源无误。
INVALIDPARAMETER_CANNOTFINDFACEERROR = 'InvalidParameter.CannotFindFaceError'

# 图片中没有人脸
INVALIDPARAMETER_CANNOTFINDFACEINPICTURE = 'InvalidParameter.CannotFindFaceInPicture'

# 从指定URL读取视频失败。
INVALIDPARAMETER_CANNOTREADVIDEOFROMURLERROR = 'InvalidParameter.CannotReadVideoFromUrlError'

# 裁剪帧失败
INVALIDPARAMETER_CLIPPINGFRAMEFAILED = 'InvalidParameter.ClippingFrameFailed'

# 计算相似度失败
INVALIDPARAMETER_COMPUTATIONALSIMILARITYFAILED = 'InvalidParameter.ComputationalSimilarityFailed'

# 添加 Face 人脸失败
INVALIDPARAMETER_CREATEFACEFAILED = 'InvalidParameter.CreateFaceFailed'

# 添加 Person 个体失败
INVALIDPARAMETER_CREATEPERSONFAILED = 'InvalidParameter.CreatePersonFailed'

# 人脸检测失败
INVALIDPARAMETER_FACEDETECTEDFAILED = 'InvalidParameter.FaceDetectedFailed'

# 删除face人脸失败，不存在该faceid
INVALIDPARAMETER_FACENOTEXIST = 'InvalidParameter.FaceNotExist'

# 人脸不存在
INVALIDPARAMETER_FACENOTEXISTED = 'InvalidParameter.FaceNotExisted'

# 超出单次检索的人脸数上线
INVALIDPARAMETER_FACENUMBEREXCEEDLIMITOFSINGLEDETECTION = 'InvalidParameter.FaceNumberExceedLimitOfSingleDetection'

# 该个体人脸已经到最大值
INVALIDPARAMETER_FACENUMBERLIMIT = 'InvalidParameter.FaceNumberLimit'

# 人脸配准失败
INVALIDPARAMETER_FACEREGISTRATIONFAILED = 'InvalidParameter.FaceRegistrationFailed'

# 人脸检索失败
INVALIDPARAMETER_FACERETRIEVALFAILED = 'InvalidParameter.FaceRetrievalFailed'

# 人脸太小
INVALIDPARAMETER_FACETOOSMALL = 'InvalidParameter.FaceTooSmall'

# 解码图片失败
INVALIDPARAMETER_FAILEDTODECODEIMAGE = 'InvalidParameter.FailedToDecodeImage'

# 特征提取失败
INVALIDPARAMETER_FEATUREEXTRACTIONFAILED = 'InvalidParameter.FeatureExtractionFailed'

# 输入内容为空
INVALIDPARAMETER_FILECONTENTEMPTY = 'InvalidParameter.FileContentEmpty'

# 输入图片无法解码
INVALIDPARAMETER_IMAGEDECODEFAILED = 'InvalidParameter.ImageDecodeFailed'

# 图片太大
INVALIDPARAMETER_IMAGETOOLARGE = 'InvalidParameter.ImageTooLarge'

# 图片太小
INVALIDPARAMETER_IMAGETOOSMALL = 'InvalidParameter.ImageTooSmall'

# 不支持的 FileType
INVALIDPARAMETER_INVALIDFILETYPE = 'InvalidParameter.InvalidFileType'

# 无效的语言类型，只支持0 英文，1 中文
INVALIDPARAMETER_INVALIDLANG = 'InvalidParameter.InvalidLang'

# 资源标识符应为字母、数字或者下划线组成
INVALIDPARAMETER_INVALIDRESOURCEIDENTIFY = 'InvalidParameter.InvalidResourceIdentify'

# 名称应为60个字符内的汉字、字母、数字或者下划线组成
INVALIDPARAMETER_INVALIDRESOURCENAME = 'InvalidParameter.InvalidResourceName'

# 分片序号错误
INVALIDPARAMETER_INVALIDSEQID = 'InvalidParameter.InvalidSeqId'

# 输入音频文件无效
INVALIDPARAMETER_INVALIDURL = 'InvalidParameter.InvalidUrl'

# 任务查询失败，请检查任务标识符后重试
INVALIDPARAMETER_JOBNOTVALID = 'InvalidParameter.JobNotValid'

# 员库中尚未有任何人员，请确认输入人员库ID无误。
INVALIDPARAMETER_LIBHAVENOPERSON = 'InvalidParameter.LibHaveNoPerson'

# 请确认输入人员库ID。
INVALIDPARAMETER_LIBISEMPTY = 'InvalidParameter.LibIsEmpty'

# 人员库不存在
INVALIDPARAMETER_LIBRARYNOTEXISTED = 'InvalidParameter.LibraryNotExisted'

# 人脸质量低，包括不清晰
INVALIDPARAMETER_LOWQUALITYPICTURE = 'InvalidParameter.LowQualityPicture'

# 服务不存在
INVALIDPARAMETER_NOSUCHSERVICE = 'InvalidParameter.NoSuchService'

# 非人员考勤任务
INVALIDPARAMETER_NOTATTENDANCEJOB = 'InvalidParameter.NotAttendanceJob'

# 人脸角度pitch不合法
INVALIDPARAMETER_NOTVALIDPITCH = 'InvalidParameter.NotValidPitch'

# 人脸角度row不合法
INVALIDPARAMETER_NOTVALIDROW = 'InvalidParameter.NotValidRow'

# 人脸角度yaw不合法
INVALIDPARAMETER_NOTVALIDYAW = 'InvalidParameter.NotValidYaw'

# 指定人员不存在
INVALIDPARAMETER_PERSONEXISTED = 'InvalidParameter.PersonExisted'

# 人员标识不合法
INVALIDPARAMETER_PERSONIDNOTVALID = 'InvalidParameter.PersonIdNotValid'

# 删除person个体失败，不存在该个体
INVALIDPARAMETER_PERSONNOTEXIST = 'InvalidParameter.PersonNotExist'

# 人员不存在
INVALIDPARAMETER_PERSONNOTEXISTED = 'InvalidParameter.PersonNotExisted'

# 人员未注册
INVALIDPARAMETER_PERSONNOTREGISTERED = 'InvalidParameter.PersonNotRegistered'

# 任务处理中，请稍后查询。
INVALIDPARAMETER_PROCESSUNREADY = 'InvalidParameter.ProcessUnReady'

# 资源名称需要保持唯一
INVALIDPARAMETER_RESOURCENAMEDUPLICATE = 'InvalidParameter.ResourceNameDuplicate'

# 任务执行失败，请确保拉流地址稳定
INVALIDPARAMETER_STATUSJOBFAILED = 'InvalidParameter.StatusJobFailed'

# 任务不存在
INVALIDPARAMETER_STATUSJOBNOTFOUND = 'InvalidParameter.StatusJobNotFound'

# 任务未完成
INVALIDPARAMETER_STATUSJOBUNFINISHED = 'InvalidParameter.StatusJobUnfinished'

# 没有找到摄像头
INVALIDPARAMETER_STATUSNOCAMERAFOUND = 'InvalidParameter.StatusNoCameraFound'

# 图片中含有多张人脸
INVALIDPARAMETER_TOOMANYFACE = 'InvalidParameter.TooManyFace'

# 轨迹追踪失败
INVALIDPARAMETER_TRACKINGFAILED = 'InvalidParameter.TrackingFailed'

# 不支持MOV类型文件
INVALIDPARAMETER_UNSUPPORTEDFILETYPEMOV = 'InvalidParameter.UnsupportedFileTypeMov'

# 视频尺寸不符合要求(1080p及以下)
INVALIDPARAMETER_UNSUPPORTEDVIDEOSIZE = 'InvalidParameter.UnsupportedVideoSize'

# 任务已经启动分析，请勿重复提交。
INVALIDPARAMETER_VIDEOALREDYPROCESSEDERROR = 'InvalidParameter.VideoAlredyProcessedError'

# 获取请求url http包体失败。
INVALIDPARAMETERVALUE_GETHTTPBODYERROR = 'InvalidParameterValue.GetHttpBodyError'

# 人员库自定义描述字段数组长度超过限制。最多可以创建5个。
INVALIDPARAMETERVALUE_GROUPEXDESCRIPTIONSEXCEED = 'InvalidParameterValue.GroupExDescriptionsExceed'

# 人员库自定义描述字段名称不可重复。
INVALIDPARAMETERVALUE_GROUPEXDESCRIPTIONSNAMEIDENTICAL = 'InvalidParameterValue.GroupExDescriptionsNameIdentical'

# 人员库自定义描述字段名称包含非法字符。人员库自定义描述字段名称只支持中英文、-、_、数字。
INVALIDPARAMETERVALUE_GROUPEXDESCRIPTIONSNAMEILLEGAL = 'InvalidParameterValue.GroupExDescriptionsNameIllegal'

# 人员库自定义描述字段名称长度超出限制。
INVALIDPARAMETERVALUE_GROUPEXDESCRIPTIONSNAMETOOLONG = 'InvalidParameterValue.GroupExDescriptionsNameTooLong'

# 图片错误
INVALIDPARAMETERVALUE_IMAGEILLEGAL = 'InvalidParameterValue.ImageIllegal'

# 分片序号错误。
INVALIDPARAMETERVALUE_INVALIDSEQID = 'InvalidParameterValue.InvalidSeqId'

# 未支持的功能。
INVALIDPARAMETERVALUE_NOTSUPPORTEDFUNCTIONERROR = 'InvalidParameterValue.NotSupportedFunctionError'

# 人员自定义描述字段数组长度超过限制。最多5个。
INVALIDPARAMETERVALUE_PERSONEXDESCRIPTIONINFOSEXCEED = 'InvalidParameterValue.PersonExDescriptionInfosExceed'

# 该教室的摄像头数量超出最大限制
LIMITEXCEEDED_STATUSCAMERACOUNTOVERMAX = 'LimitExceeded.StatusCameraCountOverMax'

# 资源不存在
RESOURCENOTFOUND = 'ResourceNotFound'

# 无法找到精彩集锦任务ID，请确认输入JobId无误。
RESOURCENOTFOUND_HLJOBIDNOTFOUND = 'ResourceNotFound.HLJobIdNotFound'

# 评估之前没有初始化或已过期。
RESOURCEUNAVAILABLE_CANNOTFINDSESSION = 'ResourceUnavailable.CannotFindSession'

# 提交任务时获取拉流地址失败，请确认该教室的摄像头都配置好
RESOURCEUNAVAILABLE_STATUSQUERYSTREAMFAILED = 'ResourceUnavailable.StatusQueryStreamFailed'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class EvaluationRequest(AbstractModel):
    """Evaluation请求参数结构体

    """

    def __init__(self):
        r"""
        :param SessionId: 图片唯一标识，一张图片一个SessionId；
        :type SessionId: str
        :param Image: 图片数据，需要使用base64对图片的二进制数据进行编码，与url参数二者填一即可；
        :type Image: str
        :param HcmAppid: 业务应用ID，与账号应用APPID无关，是用来方便客户管理服务的参数，新的 HcmAppid 可以在[控制台](https://console.cloud.tencent.com/hcm)【应用管理】下新建。
        :type HcmAppid: str
        :param Url: 图片url，与Image参数二者填一即可；
        :type Url: str
        :param SupportHorizontalImage: 横屏拍摄开关，若开启则支持传输横屏拍摄的图片；
        :type SupportHorizontalImage: bool
        :param RejectNonArithmeticImage: 拒绝非速算图（如风景图、人物图）开关，若开启，则遇到非速算图会快速返回拒绝的结果，但极端情况下可能会影响评估结果（比如算式截图贴到风景画里可能被判为非速算图直接返回了）。
        :type RejectNonArithmeticImage: bool
        :param IsAsync: 异步模式标识，0：同步模式，1：异步模式。默认为同步模式
        :type IsAsync: int
        :param EnableDispRelatedVertical: 是否展开耦合算式中的竖式计算
        :type EnableDispRelatedVertical: bool
        :param EnableDispMidresult: 是否展示竖式算式的中间结果和格式控制字符
        :type EnableDispMidresult: bool
        :param EnablePdfRecognize: 是否开启pdf识别，默认开启
        :type EnablePdfRecognize: bool
        :param PdfPageIndex: pdf页码，从0开始，默认为0
        :type PdfPageIndex: int
        :param LaTex: 是否返回LaTex，默认为0返回普通格式，设置成1返回LaTex格式
        :type LaTex: int
        :param RejectVagueArithmetic: 用于选择是否拒绝模糊题 目。打开则丢弃模糊题目， 不进行后续的判题返回结 果。
        :type RejectVagueArithmetic: bool
        """
        self.SessionId = None
        self.Image = None
        self.HcmAppid = None
        self.Url = None
        self.SupportHorizontalImage = None
        self.RejectNonArithmeticImage = None
        self.IsAsync = None
        self.EnableDispRelatedVertical = None
        self.EnableDispMidresult = None
        self.EnablePdfRecognize = None
        self.PdfPageIndex = None
        self.LaTex = None
        self.RejectVagueArithmetic = None


    def _deserialize(self, params):
        self.SessionId = params.get("SessionId")
        self.Image = params.get("Image")
        self.HcmAppid = params.get("HcmAppid")
        self.Url = params.get("Url")
        self.SupportHorizontalImage = params.get("SupportHorizontalImage")
        self.RejectNonArithmeticImage = params.get("RejectNonArithmeticImage")
        self.IsAsync = params.get("IsAsync")
        self.EnableDispRelatedVertical = params.get("EnableDispRelatedVertical")
        self.EnableDispMidresult = params.get("EnableDispMidresult")
        self.EnablePdfRecognize = params.get("EnablePdfRecognize")
        self.PdfPageIndex = params.get("PdfPageIndex")
        self.LaTex = params.get("LaTex")
        self.RejectVagueArithmetic = params.get("RejectVagueArithmetic")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class EvaluationResponse(AbstractModel):
    """Evaluation返回参数结构体

    """

    def __init__(self):
        r"""
        :param SessionId: 图片唯一标识，一张图片一个SessionId；
        :type SessionId: str
        :param Items: 识别出的算式信息；
注意：此字段可能返回 null，表示取不到有效值。
        :type Items: list of Item
        :param TaskId: 任务 id，用于查询接口
        :type TaskId: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.SessionId = None
        self.Items = None
        self.TaskId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SessionId = params.get("SessionId")
        if params.get("Items") is not None:
            self.Items = []
            for item in params.get("Items"):
                obj = Item()
                obj._deserialize(item)
                self.Items.append(obj)
        self.TaskId = params.get("TaskId")
        self.RequestId = params.get("RequestId")


class Item(AbstractModel):
    """识别出的算术式信息及评估结果

    """

    def __init__(self):
        r"""
        :param Item: 识别的算式是否正确，算式运算结果: ‘YES’:正确 ‘NO’: 错误 ‘NA’: 非法参数
        :type Item: str
        :param ItemString: 识别出的算式，识别出的文本行字符串
        :type ItemString: str
        :param ItemCoord: 识别的算式在图片上的位置信息，文本行在旋转纠正之后的图像中的像素坐 标，表示为(左上角 x, 左上角 y，宽 width， 高 height)
        :type ItemCoord: :class:`tencentcloud.hcm.v20181106.models.ItemCoord`
        :param Answer: 错题推荐答案，算式运算结果正确返回为 ""，算式运算结果错误返回推荐答案 (注:暂不支持多个关系运算符(如 1<10<7)、 无关系运算符(如 frac(1,2)+frac(2,3))、单 位换算(如 1 元=100 角)错题的推荐答案 返回)
        :type Answer: str
        :param ExpressionType: 算式题型编号，如加减乘除四则题型，具体题型及编号如下：1 加减乘除四则 2 加减乘除已知结果求运算因子3 判断大小 4 约等于估算 5 带余数除法 6 分数四则运算 7 单位换算 8 竖式加减法 9 竖式乘除法 10 脱式计算 11 解方程
注意：此字段可能返回 null，表示取不到有效值。
        :type ExpressionType: str
        :param ItemConf: 文本行置信度
注意：此字段可能返回 null，表示取不到有效值。
        :type ItemConf: float
        :param QuestionId: 用于标识题目 id，如果有若干算式属于同一 题，则其对应的 id 相同。
注意：此字段可能返回 null，表示取不到有效值。
        :type QuestionId: str
        """
        self.Item = None
        self.ItemString = None
        self.ItemCoord = None
        self.Answer = None
        self.ExpressionType = None
        self.ItemConf = None
        self.QuestionId = None


    def _deserialize(self, params):
        self.Item = params.get("Item")
        self.ItemString = params.get("ItemString")
        if params.get("ItemCoord") is not None:
            self.ItemCoord = ItemCoord()
            self.ItemCoord._deserialize(params.get("ItemCoord"))
        self.Answer = params.get("Answer")
        self.ExpressionType = params.get("ExpressionType")
        self.ItemConf = params.get("ItemConf")
        self.QuestionId = params.get("QuestionId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ItemCoord(AbstractModel):
    """目标算式在图片上的坐标信息

    """

    def __init__(self):
        r"""
        :param Height: 算式高度
        :type Height: int
        :param Width: 算式宽度
        :type Width: int
        :param X: 算式图的左上角横坐标
        :type X: int
        :param Y: 算式图的左上角纵坐标
        :type Y: int
        """
        self.Height = None
        self.Width = None
        self.X = None
        self.Y = None


    def _deserialize(self, params):
        self.Height = params.get("Height")
        self.Width = params.get("Width")
        self.X = params.get("X")
        self.Y = params.get("Y")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 查询对象存储失败。
FAILEDOPERATION_COSERROR = 'FailedOperation.CosError'

# 获取上传配置信息错误。
FAILEDOPERATION_COSPROPERTIESERROR = 'FailedOperation.CosPropertiesError'

# 创建订单失败。
FAILEDOPERATION_CREATEORDERFAILED = 'FailedOperation.CreateOrderFailed'

# 数据库错误。
FAILEDOPERATION_DBERROR = 'FailedOperation.DBError'

# 操作失败或者网络超时。
FAILEDOPERATION_GCSERROR = 'FailedOperation.GcsError'

# 获取VPC网络信息失败。
FAILEDOPERATION_GETVPCFAILED = 'FailedOperation.GetVpcFailed'

# 备份导入任务锁定失败。
FAILEDOPERATION_MIGRATIONLOCKERROR = 'FailedOperation.MigrationLockError'

# 查询订单失败。
FAILEDOPERATION_QUERYORDERFAILED = 'FailedOperation.QueryOrderFailed'

# 计费相关错误，查询价格失败。
FAILEDOPERATION_QUERYPRICEFAILED = 'FailedOperation.QueryPriceFailed'

# 安全组操作失败。
FAILEDOPERATION_SECURITYGROUPOPERATIONERROR = 'FailedOperation.SecurityGroupOperationError'

# 操作网络失败或者超时。
FAILEDOPERATION_VPCERROR = 'FailedOperation.VPCError'

# 内部错误。
INTERNALERROR = 'InternalError'

# CAM鉴权请求失败。
INTERNALERROR_CAMAUTHFAILED = 'InternalError.CamAuthFailed'

# COS接口错误。
INTERNALERROR_COSERROR = 'InternalError.CosError'

# 流程创建失败。
INTERNALERROR_CREATEFLOWFAILED = 'InternalError.CreateFlowFailed'

# 数据库连接错误。
INTERNALERROR_DBCONNECTERROR = 'InternalError.DBConnectError'

# 数据库错误。
INTERNALERROR_DBERROR = 'InternalError.DBError'

# GCS接口错误。
INTERNALERROR_GCSERROR = 'InternalError.GcsError'

# 获取临时密钥错误。
INTERNALERROR_STSERROR = 'InternalError.StsError'

# 系统错误。
INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'

# 未知错误。
INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'

# VPC错误。
INTERNALERROR_VPCERROR = 'InternalError.VPCError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 输入错误。
INVALIDPARAMETER_INPUTILLEGAL = 'InvalidParameter.InputIllegal'

# 接口不存在。
INVALIDPARAMETER_INTERFACENAMENOTFOUND = 'InvalidParameter.InterfaceNameNotFound'

# 参数断言转换错误。
INVALIDPARAMETER_PARAMSASSERTFAILED = 'InvalidParameter.ParamsAssertFailed'

# 支付订单失败。
INVALIDPARAMETER_PAYORDERFAILED = 'InvalidParameter.PayOrderFailed'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 账号已经存在。
INVALIDPARAMETERVALUE_ACCOUNTEXIST = 'InvalidParameterValue.AccountExist'

# 账户名称不合法。
INVALIDPARAMETERVALUE_ACCOUNTNAMEISILLEGAL = 'InvalidParameterValue.AccountNameIsIllegal'

# 账号名称不允许是保留字。
INVALIDPARAMETERVALUE_ACCOUNTNAMEISKEYWORDS = 'InvalidParameterValue.AccountNameIsKeyWords'

# 账户备注内容不合法。
INVALIDPARAMETERVALUE_ACCOUNTREMARKISILLEGAL = 'InvalidParameterValue.AccountRemarkIsIllegal'

# 管理员账号只能申请一个。
INVALIDPARAMETERVALUE_ADMINACCOUNTNOTUNIQUE = 'InvalidParameterValue.AdminAccountNotUnique'

# 备份名称存在非法字符。
INVALIDPARAMETERVALUE_BACKUPNAMEISILLEGAL = 'InvalidParameterValue.BackupNameIsIllegal'

# 购买实例数量错误。
INVALIDPARAMETERVALUE_BADGOODSNUM = 'InvalidParameterValue.BadGoodsNum'

# 数据库字符集设置错误。
INVALIDPARAMETERVALUE_CHARSETISILLEGAL = 'InvalidParameterValue.CharsetIsIllegal'

# 上传路径错误。
INVALIDPARAMETERVALUE_COSPATHERROR = 'InvalidParameterValue.CosPathError'

# 计费类型错误。
INVALIDPARAMETERVALUE_COSTTYPENOTSUPPORTED = 'InvalidParameterValue.CostTypeNotSupported'

# 数据库名称包含非法字符。
INVALIDPARAMETERVALUE_DBCHARILLEGAL = 'InvalidParameterValue.DBCharIllegal'

# 数据库已经存在。
INVALIDPARAMETERVALUE_DBEXIST = 'InvalidParameterValue.DBExist'

# 数据库名称不允许是保留字。
INVALIDPARAMETERVALUE_DBNAMEISKEYWRODS = 'InvalidParameterValue.DBNameIsKeyWrods'

# 数据库名称不能为空。
INVALIDPARAMETERVALUE_DBNAMENOTNULL = 'InvalidParameterValue.DBNameNotNull'

# 数据库重命名名称一样。
INVALIDPARAMETERVALUE_DBNAMESAME = 'InvalidParameterValue.DBNameSame'

# 数据库备注内容不合法。
INVALIDPARAMETERVALUE_DATABASEREMARKISILLEGAL = 'InvalidParameterValue.DataBaseRemarkIsIllegal'

# 参数错误，GRANT 值非法。
INVALIDPARAMETERVALUE_GRANTISILLEGAL = 'InvalidParameterValue.GrantIsIllegal'

# 地域错误。
INVALIDPARAMETERVALUE_ILLEGALREGION = 'InvalidParameterValue.IllegalRegion'

# 实例规格信息错误。
INVALIDPARAMETERVALUE_ILLEGALSPEC = 'InvalidParameterValue.IllegalSpec'

# 可用区ID错误。
INVALIDPARAMETERVALUE_ILLEGALZONE = 'InvalidParameterValue.IllegalZone'

# 实例扩容容量低于当前容量。
INVALIDPARAMETERVALUE_INSTANCEEXPANDVOLUMELOW = 'InvalidParameterValue.InstanceExpandVolumeLow'

# 实例名称存在非法字符。
INVALIDPARAMETERVALUE_INSTANCENAMEISILLEGAL = 'InvalidParameterValue.InstanceNameIsIllegal'

# 迁移名称包含非法字符。
INVALIDPARAMETERVALUE_MIGRATIONNAMEISILLEGAL = 'InvalidParameterValue.MigrationNameIsIllegal'

# 可选参数[enable, disable]。
INVALIDPARAMETERVALUE_MODIFYTYPEVALUEINVALID = 'InvalidParameterValue.ModifyTypeValueInvalid'

# 是CVM类型。
INVALIDPARAMETERVALUE_ONCVMTYPENOTSUPPORTED = 'InvalidParameterValue.OnCvmTypeNotSupported'

# 参数类型错误。
INVALIDPARAMETERVALUE_PARAMETERTYPEERROR = 'InvalidParameterValue.ParameterTypeError'

# 账号密码非法。
INVALIDPARAMETERVALUE_PASSWORDISILLEGAL = 'InvalidParameterValue.PasswordIsIllegal'

# 数据库权限设置错误。
INVALIDPARAMETERVALUE_PRIVILEGEISILLEGAL = 'InvalidParameterValue.PrivilegeIsIllegal'

# 发布订阅名称不符合规范。
INVALIDPARAMETERVALUE_PUBSUBNAMEISILLEGAL = 'InvalidParameterValue.PubSubNameIsIllegal'

# 只读组名称包含非法字符。
INVALIDPARAMETERVALUE_ROGROUPNAMEISILLEGAL = 'InvalidParameterValue.RoGroupNameIsIllegal'

# 只读组状态不正确。
INVALIDPARAMETERVALUE_ROGROUPSTATUSISILLEGAL = 'InvalidParameterValue.RoGroupStatusIsIllegal'

# 安全组ID非法。
INVALIDPARAMETERVALUE_SECURITYGROUPIDISILLEGAL = 'InvalidParameterValue.SecurityGroupIdIsIllegal'

# 数据库超过限制。
LIMITEXCEEDED_TOOMANYDB = 'LimitExceeded.TooManyDB'

# 已经存在一个准备启动的增量导入任务。
RESOURCEINUSE_INCREMENTALMIGRATIONEXIST = 'ResourceInUse.IncrementalMigrationExist'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# 账号不存在。
RESOURCENOTFOUND_ACCOUNTNOTEXIST = 'ResourceNotFound.AccountNotExist'

# 备份不存在。
RESOURCENOTFOUND_BACKUPNOTFOUND = 'ResourceNotFound.BackupNotFound'

# 数据库不存在。
RESOURCENOTFOUND_DBNOTEXIT = 'ResourceNotFound.DBNotExit'

# 数据库不存在。
RESOURCENOTFOUND_DBNOTFOUND = 'ResourceNotFound.DBNotFound'

# 全量备份导入任务不存在。
RESOURCENOTFOUND_FULLBACKUPMIGRATIONNOTEXIST = 'ResourceNotFound.FullBackupMigrationNotExist'

# 增量备份导入任务不存在。
RESOURCENOTFOUND_INCREBACKUPMIGRATIONNOTEXIST = 'ResourceNotFound.IncreBackupMigrationNotExist'

# 实例不存在。
RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'

# 参数未找到。
RESOURCENOTFOUND_PARAMSNOTFOUND = 'ResourceNotFound.ParamsNotFound'

# VPC网络不存在。
RESOURCENOTFOUND_VPCNOTEXIST = 'ResourceNotFound.VpcNotExist'

# 账号状态无效。
RESOURCEUNAVAILABLE_ACCOUNTINVALIDSTATUS = 'ResourceUnavailable.AccountInvalidStatus'

# 恢复类型不支持增量备份导入。
RESOURCEUNAVAILABLE_BACKUPMIGRATIONRECOVERYTYPEERR = 'ResourceUnavailable.BackupMigrationRecoveryTypeErr'

# 离线恢复任务状态错误。
RESOURCEUNAVAILABLE_COSSTATUSERR = 'ResourceUnavailable.CosStatusErr'

# 数据库状态无效。
RESOURCEUNAVAILABLE_DBINVALIDSTATUS = 'ResourceUnavailable.DBInvalidStatus'

# 实例迁移地域非法。
RESOURCEUNAVAILABLE_INSTANCEMIGRATEREGIONILLEGAL = 'ResourceUnavailable.InstanceMigrateRegionIllegal'

# 实例迁移状态无效。
RESOURCEUNAVAILABLE_INSTANCEMIGRATESTATUSINVALID = 'ResourceUnavailable.InstanceMigrateStatusInvalid'

# 实例状态无效。
RESOURCEUNAVAILABLE_INSTANCESTATUSINVALID = 'ResourceUnavailable.InstanceStatusInvalid'

# 不支持只读实例。
RESOURCEUNAVAILABLE_NOTSUPPORTROINSTANCE = 'ResourceUnavailable.NotSupportRoInstance'

# VPC不存在。
RESOURCEUNAVAILABLE_VPCNOTEXIST = 'ResourceUnavailable.VpcNotExist'

# 未授权操作。
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# cam鉴权错误。
UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'

# 未知参数错误。
UNKNOWNPARAMETER = 'UnknownParameter'

# 不支持重复操作。
UNSUPPORTEDOPERATION_NOTSUPPORTREPEAT = 'UnsupportedOperation.NotSupportRepeat'

# 上传类型错误。
UNSUPPORTEDOPERATION_UPLOADTYPEERROR = 'UnsupportedOperation.UploadTypeError'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class FileTranslateRequest(AbstractModel):
    """FileTranslate请求参数结构体

    """

    def __init__(self):
        r"""
        :param Source: 源语言，支持
zh:简体中文
zh-HK：繁体中文
zh-TW : 繁体中文
zh-TR:  繁体中文
en ：英语
ar：阿拉伯语
de：德语
es：西班牙语
fr：法语
it：意大利语
ja：日语
pt：葡萄牙语
ru：俄语
ko：韩语
km：高棉语
lo：老挝语
        :type Source: str
        :param Target: 目标语言，各源语言的目标语言支持列表如下
zh（简体中文）： en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
zh-HK（繁体中文） ：en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
zh-TW（繁体中文）：en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
zh-TR 繁体中文 : en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
en （英语） ：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、 zh-TR(繁体中文）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
ar（阿拉伯语） ：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
de（德语 ）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
es（西班牙语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
fr（法语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
it（意大利语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
ja（日语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
pt（葡萄牙语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
ru（俄语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
ko（韩语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
km（高棉语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
        :type Target: str
        :param DocumentType: 文档类型：可支持以下几种(pdf,docx,pptx,xlsx,txt,xml,html,markdown,properties)
        :type DocumentType: str
        :param SourceType: 数据来源，0：url，1：直接传文件编码后数据
        :type SourceType: int
        :param Url: 需要翻译文件url
        :type Url: str
        :param BasicDocumentType: 原始文档类型
        :type BasicDocumentType: str
        :param CallbackUrl: 回调url
        :type CallbackUrl: str
        :param Data: 文件数据，当SourceType 值为1时必须填写，为0可不写。要base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。数据要小于5MB。
        :type Data: str
        """
        self.Source = None
        self.Target = None
        self.DocumentType = None
        self.SourceType = None
        self.Url = None
        self.BasicDocumentType = None
        self.CallbackUrl = None
        self.Data = None


    def _deserialize(self, params):
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.DocumentType = params.get("DocumentType")
        self.SourceType = params.get("SourceType")
        self.Url = params.get("Url")
        self.BasicDocumentType = params.get("BasicDocumentType")
        self.CallbackUrl = params.get("CallbackUrl")
        self.Data = params.get("Data")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class FileTranslateResponse(AbstractModel):
    """FileTranslate返回参数结构体

    """

    def __init__(self):
        r"""
        :param Data: 文件翻译的请求返回结果，包含结果查询需要的TaskId
        :type Data: :class:`tencentcloud.tmt.v20180321.models.Task`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = Task()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class GetFileTranslateData(AbstractModel):
    """查询文件翻译任务

    """

    def __init__(self):
        r"""
        :param TaskId: 任务ID
        :type TaskId: str
        :param Status: 状态
        :type Status: str
        :param FileData: 文件数据
注意：此字段可能返回 null，表示取不到有效值。
        :type FileData: str
        :param Message: 错误提示
注意：此字段可能返回 null，表示取不到有效值。
        :type Message: str
        :param Progress: 翻译进度
注意：此字段可能返回 null，表示取不到有效值。
        :type Progress: int
        """
        self.TaskId = None
        self.Status = None
        self.FileData = None
        self.Message = None
        self.Progress = None


    def _deserialize(self, params):
        self.TaskId = params.get("TaskId")
        self.Status = params.get("Status")
        self.FileData = params.get("FileData")
        self.Message = params.get("Message")
        self.Progress = params.get("Progress")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetFileTranslateRequest(AbstractModel):
    """GetFileTranslate请求参数结构体

    """

    def __init__(self):
        r"""
        :param TaskId: 任务ID
        :type TaskId: str
        """
        self.TaskId = None


    def _deserialize(self, params):
        self.TaskId = params.get("TaskId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetFileTranslateResponse(AbstractModel):
    """GetFileTranslate返回参数结构体

    """

    def __init__(self):
        r"""
        :param Data: 任务id
        :type Data: :class:`tencentcloud.tmt.v20180321.models.GetFileTranslateData`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = GetFileTranslateData()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class ImageRecord(AbstractModel):
    """图片翻译结果

    """

    def __init__(self):
        r"""
        :param Value: 图片翻译结果
        :type Value: list of ItemValue
        """
        self.Value = None


    def _deserialize(self, params):
        if params.get("Value") is not None:
            self.Value = []
            for item in params.get("Value"):
                obj = ItemValue()
                obj._deserialize(item)
                self.Value.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ImageTranslateRequest(AbstractModel):
    """ImageTranslate请求参数结构体

    """

    def __init__(self):
        r"""
        :param SessionUuid: 唯一id，返回时原样返回
        :type SessionUuid: str
        :param Scene: doc:文档扫描
        :type Scene: str
        :param Data: 图片数据的Base64字符串，图片大小上限为4M，建议对源图片进行一定程度压缩
        :type Data: str
        :param Source: 源语言，支持语言列表：<li> auto：自动识别（识别为一种语言）</li> <li>zh：简体中文</li> <li>zh-TW：繁体中文</li> <li>en：英语</li> <li>ja：日语</li> <li>ko：韩语</li> <li>ru：俄语</li> <li>fr：法语</li> <li>de：德语</li> <li>it：意大利语</li> <li>es：西班牙语</li> <li>pt：葡萄牙语</li> <li>ms：马来西亚语</li> <li>th：泰语</li><li>vi：越南语</li>
        :type Source: str
        :param Target: 目标语言，各源语言的目标语言支持列表如下：
<li>zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
<li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
<li>en（英语）：zh（中文）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
<li>ja（日语）：zh（中文）、en（英语）、ko（韩语）</li>
<li>ko（韩语）：zh（中文）、en（英语）、ja（日语）</li>
<li>ru：俄语：zh（中文）、en（英语）</li>
<li>fr：法语：zh（中文）、en（英语）</li>
<li>de：德语：zh（中文）、en（英语）</li>
<li>it：意大利语：zh（中文）、en（英语）</li>
<li>es：西班牙语：zh（中文）、en（英语）</li>
<li>pt：葡萄牙语：zh（中文）、en（英语）</li>
<li>ms：马来西亚语：zh（中文）、en（英语）</li>
<li>th：泰语：zh（中文）、en（英语）</li>
<li>vi：越南语：zh（中文）、en（英语）</li>
        :type Target: str
        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
        :type ProjectId: int
        """
        self.SessionUuid = None
        self.Scene = None
        self.Data = None
        self.Source = None
        self.Target = None
        self.ProjectId = None


    def _deserialize(self, params):
        self.SessionUuid = params.get("SessionUuid")
        self.Scene = params.get("Scene")
        self.Data = params.get("Data")
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.ProjectId = params.get("ProjectId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ImageTranslateResponse(AbstractModel):
    """ImageTranslate返回参数结构体

    """

    def __init__(self):
        r"""
        :param SessionUuid: 请求的SessionUuid返回
        :type SessionUuid: str
        :param Source: 源语言
        :type Source: str
        :param Target: 目标语言
        :type Target: str
        :param ImageRecord: 图片翻译结果，翻译结果按识别的文本每一行独立翻译，后续会推出按段落划分并翻译的版本
        :type ImageRecord: :class:`tencentcloud.tmt.v20180321.models.ImageRecord`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.SessionUuid = None
        self.Source = None
        self.Target = None
        self.ImageRecord = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SessionUuid = params.get("SessionUuid")
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        if params.get("ImageRecord") is not None:
            self.ImageRecord = ImageRecord()
            self.ImageRecord._deserialize(params.get("ImageRecord"))
        self.RequestId = params.get("RequestId")


class ItemValue(AbstractModel):
    """翻译结果

    """

    def __init__(self):
        r"""
        :param SourceText: 识别出的源文
        :type SourceText: str
        :param TargetText: 翻译后的译文
        :type TargetText: str
        :param X: X坐标
        :type X: int
        :param Y: Y坐标
        :type Y: int
        :param W: 宽度
        :type W: int
        :param H: 高度
        :type H: int
        """
        self.SourceText = None
        self.TargetText = None
        self.X = None
        self.Y = None
        self.W = None
        self.H = None


    def _deserialize(self, params):
        self.SourceText = params.get("SourceText")
        self.TargetText = params.get("TargetText")
        self.X = params.get("X")
        self.Y = params.get("Y")
        self.W = params.get("W")
        self.H = params.get("H")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class LanguageDetectRequest(AbstractModel):
    """LanguageDetect请求参数结构体

    """

    def __init__(self):
        r"""
        :param Text: 待识别的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败。单次请求的文本长度需要低于2000。
        :type Text: str
        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
        :type ProjectId: int
        """
        self.Text = None
        self.ProjectId = None


    def _deserialize(self, params):
        self.Text = params.get("Text")
        self.ProjectId = params.get("ProjectId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class LanguageDetectResponse(AbstractModel):
    """LanguageDetect返回参数结构体

    """

    def __init__(self):
        r"""
        :param Lang: 识别出的语言种类，参考语言列表
<li> zh : 中文 </li> <li> en : 英文 </li><li> jp : 日语 </li> <li> kr : 韩语 </li><li> de : 德语 </li><li> fr : 法语 </li><li> es : 西班牙文 </li> <li> it : 意大利文 </li><li> tr : 土耳其文 </li><li> ru : 俄文 </li><li> pt : 葡萄牙文 </li><li> vi : 越南文 </li><li> id : 印度尼西亚文 </li><li> ms : 马来西亚文 </li><li> th : 泰文 </li>
        :type Lang: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Lang = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Lang = params.get("Lang")
        self.RequestId = params.get("RequestId")


class SpeechTranslateRequest(AbstractModel):
    """SpeechTranslate请求参数结构体

    """

    def __init__(self):
        r"""
        :param SessionUuid: 一段完整的语音对应一个SessionUuid
        :type SessionUuid: str
        :param Source: 音频中的语言类型，支持语言列表<li> zh : 中文 </li> <li> en : 英文 </li>
        :type Source: str
        :param Target: 翻译目标语言类型，支持的语言列表<li> zh : 中文 </li> <li> en : 英文 </li>
        :type Target: str
        :param AudioFormat: pcm : 146   speex : 16779154   mp3 : 83886080
        :type AudioFormat: int
        :param Seq: 语音分片的序号，从0开始
        :type Seq: int
        :param IsEnd: 是否最后一片语音分片，0-否，1-是
        :type IsEnd: int
        :param Data: 语音分片内容进行 Base64 编码后的字符串。音频内容需包含有效并可识别的文本信息。
        :type Data: str
        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
        :type ProjectId: int
        :param Mode: 识别模式，该参数已废弃
        :type Mode: str
        :param TransType: 该参数已废弃
        :type TransType: int
        """
        self.SessionUuid = None
        self.Source = None
        self.Target = None
        self.AudioFormat = None
        self.Seq = None
        self.IsEnd = None
        self.Data = None
        self.ProjectId = None
        self.Mode = None
        self.TransType = None


    def _deserialize(self, params):
        self.SessionUuid = params.get("SessionUuid")
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.AudioFormat = params.get("AudioFormat")
        self.Seq = params.get("Seq")
        self.IsEnd = params.get("IsEnd")
        self.Data = params.get("Data")
        self.ProjectId = params.get("ProjectId")
        self.Mode = params.get("Mode")
        self.TransType = params.get("TransType")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SpeechTranslateResponse(AbstractModel):
    """SpeechTranslate返回参数结构体

    """

    def __init__(self):
        r"""
        :param SessionUuid: 请求的SessionUuid直接返回
        :type SessionUuid: str
        :param RecognizeStatus: 语音识别状态 1-进行中 0-完成
        :type RecognizeStatus: int
        :param SourceText: 识别出的原文
        :type SourceText: str
        :param TargetText: 翻译出的译文
        :type TargetText: str
        :param Seq: 第几个语音分片
        :type Seq: int
        :param Source: 原语言
        :type Source: str
        :param Target: 目标语言
        :type Target: str
        :param VadSeq: 当请求的Mode参数填写bvad是，启动VadSeq。此时Seq会被设置为后台vad（静音检测）后的新序号，而VadSeq代表客户端原始Seq值
        :type VadSeq: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.SessionUuid = None
        self.RecognizeStatus = None
        self.SourceText = None
        self.TargetText = None
        self.Seq = None
        self.Source = None
        self.Target = None
        self.VadSeq = None
        self.RequestId = None


    def _deserialize(self, params):
        self.SessionUuid = params.get("SessionUuid")
        self.RecognizeStatus = params.get("RecognizeStatus")
        self.SourceText = params.get("SourceText")
        self.TargetText = params.get("TargetText")
        self.Seq = params.get("Seq")
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.VadSeq = params.get("VadSeq")
        self.RequestId = params.get("RequestId")


class Task(AbstractModel):
    """文件翻译请求的返回数据

    """

    def __init__(self):
        r"""
        :param TaskId: 任务ID，可通过此ID在轮询接口获取识别状态与结果。注意：TaskId数据类型为字符串类型
        :type TaskId: str
        """
        self.TaskId = None


    def _deserialize(self, params):
        self.TaskId = params.get("TaskId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TextTranslateBatchRequest(AbstractModel):
    """TextTranslateBatch请求参数结构体

    """

    def __init__(self):
        r"""
        :param Source: 源语言，支持： 
auto：自动识别（识别为一种语言）
zh：简体中文
zh-TW：繁体中文
en：英语
ja：日语
ko：韩语
fr：法语
es：西班牙语
it：意大利语
de：德语
tr：土耳其语
ru：俄语
pt：葡萄牙语
vi：越南语
id：印尼语
th：泰语
ms：马来西亚语
ar：阿拉伯语
hi：印地语
        :type Source: str
        :param Target: 目标语言，各源语言的目标语言支持列表如下

<li> zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
<li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
<li>en（英语）：zh（中文）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）、hi（印地语）</li>
<li>ja（日语）：zh（中文）、en（英语）、ko（韩语）</li>
<li>ko（韩语）：zh（中文）、en（英语）、ja（日语）</li>
<li>fr（法语）：zh（中文）、en（英语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>es（西班牙语）：zh（中文）、en（英语）、fr（法语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>it（意大利语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>de（德语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>tr（土耳其语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、ru（俄语）、pt（葡萄牙语）</li>
<li>ru（俄语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、pt（葡萄牙语）</li>
<li>pt（葡萄牙语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）</li>
<li>vi（越南语）：zh（中文）、en（英语）</li>
<li>id（印尼语）：zh（中文）、en（英语）</li>
<li>th（泰语）：zh（中文）、en（英语）</li>
<li>ms（马来语）：zh（中文）、en（英语）</li>
<li>ar（阿拉伯语）：en（英语）</li>
<li>hi（印地语）：en（英语）</li>
        :type Target: str
        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
        :type ProjectId: int
        :param SourceTextList: 待翻译的文本列表，批量接口可以以数组方式在一次请求中填写多个待翻译文本。文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度总和需要低于2000。
        :type SourceTextList: list of str
        """
        self.Source = None
        self.Target = None
        self.ProjectId = None
        self.SourceTextList = None


    def _deserialize(self, params):
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.ProjectId = params.get("ProjectId")
        self.SourceTextList = params.get("SourceTextList")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TextTranslateBatchResponse(AbstractModel):
    """TextTranslateBatch返回参数结构体

    """

    def __init__(self):
        r"""
        :param Source: 源语言，详见入参Target
        :type Source: str
        :param Target: 目标语言，详见入参Target
        :type Target: str
        :param TargetTextList: 翻译后的文本列表
        :type TargetTextList: list of str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Source = None
        self.Target = None
        self.TargetTextList = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.TargetTextList = params.get("TargetTextList")
        self.RequestId = params.get("RequestId")


class TextTranslateRequest(AbstractModel):
    """TextTranslate请求参数结构体

    """

    def __init__(self):
        r"""
        :param SourceText: 待翻译的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度需要低于2000。
        :type SourceText: str
        :param Source: 源语言，支持：
auto：自动识别（识别为一种语言）
zh：简体中文
zh-TW：繁体中文
en：英语
ja：日语
ko：韩语
fr：法语
es：西班牙语
it：意大利语
de：德语
tr：土耳其语
ru：俄语
pt：葡萄牙语
vi：越南语
id：印尼语
th：泰语
ms：马来西亚语
ar：阿拉伯语
hi：印地语
        :type Source: str
        :param Target: 目标语言，各源语言的目标语言支持列表如下

<li> zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
<li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
<li>en（英语）：zh（中文）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）、ar（阿拉伯语）、hi（印地语）</li>
<li>ja（日语）：zh（中文）、en（英语）、ko（韩语）</li>
<li>ko（韩语）：zh（中文）、en（英语）、ja（日语）</li>
<li>fr（法语）：zh（中文）、en（英语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>es（西班牙语）：zh（中文）、en（英语）、fr（法语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>it（意大利语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>de（德语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）</li>
<li>tr（土耳其语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、ru（俄语）、pt（葡萄牙语）</li>
<li>ru（俄语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、pt（葡萄牙语）</li>
<li>pt（葡萄牙语）：zh（中文）、en（英语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）</li>
<li>vi（越南语）：zh（中文）、en（英语）</li>
<li>id（印尼语）：zh（中文）、en（英语）</li>
<li>th（泰语）：zh（中文）、en（英语）</li>
<li>ms（马来语）：zh（中文）、en（英语）</li>
<li>ar（阿拉伯语）：en（英语）</li>
<li>hi（印地语）：en（英语）</li>
        :type Target: str
        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
        :type ProjectId: int
        :param UntranslatedText: 用来标记不希望被翻译的文本内容，如句子中的特殊符号、人名、地名等；每次请求只支持配置一个不被翻译的单词；仅支持配置人名、地名等名词，不要配置动词或短语，否则会影响翻译结果。
        :type UntranslatedText: str
        """
        self.SourceText = None
        self.Source = None
        self.Target = None
        self.ProjectId = None
        self.UntranslatedText = None


    def _deserialize(self, params):
        self.SourceText = params.get("SourceText")
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.ProjectId = params.get("ProjectId")
        self.UntranslatedText = params.get("UntranslatedText")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TextTranslateResponse(AbstractModel):
    """TextTranslate返回参数结构体

    """

    def __init__(self):
        r"""
        :param TargetText: 翻译后的文本
        :type TargetText: str
        :param Source: 源语言，详见入参Target
        :type Source: str
        :param Target: 目标语言，详见入参Target
        :type Target: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.TargetText = None
        self.Source = None
        self.Target = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TargetText = params.get("TargetText")
        self.Source = params.get("Source")
        self.Target = params.get("Target")
        self.RequestId = params.get("RequestId")